@@ -11,14 +11,6 @@
         <source>Version:</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Deepin Image Viewer is a fashion &amp; smooth image manager.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>It is featured with image management, image viewing and basic image editing.</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>AlbumBTContent</name>
@@ -257,10 +249,6 @@
         <source>Copy to clipboard</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation type="unfinished"></translation>
@@ -309,6 +297,10 @@
         <source>Add to new album</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>Importer</name>
@@ -343,7 +335,7 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Resolution</source>
+        <source>Dimension</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -450,6 +442,13 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>PrintPreviewDialog</name>
+    <message>
+        <source>Image Settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>QObject</name>
     <message>
@@ -549,10 +548,6 @@
         <source>Copy</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation type="unfinished"></translation>
@@ -621,6 +616,10 @@
         <source>Display shortcuts</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ShortcutEditor</name>
@@ -674,10 +673,6 @@
         <source>Copy</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation type="unfinished"></translation>
@@ -787,10 +782,6 @@
         <source>Rotate clockwise</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Throw to Trash</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Unfavorite</source>
         <translation type="unfinished"></translation>
@@ -799,6 +790,10 @@
         <source>Favorite</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ThumbnailWidget</name>
@@ -806,6 +801,10 @@
         <source>No image files found</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Open Image</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>TimelineBTContent</name>
@@ -872,10 +871,6 @@
         <source>Copy to clipboard</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Favorite</source>
         <translation type="unfinished"></translation>
@@ -904,6 +899,10 @@
         <source>Image info</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>TitleFrame</name>
@@ -969,6 +968,10 @@
         <source>Dark theme</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Deepin Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ViewPanel</name>
@@ -1008,10 +1011,6 @@
         <source>Copy to clipboard</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation type="unfinished"></translation>
@@ -1052,5 +1051,17 @@
         <source>Image info</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Open Image</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>All images</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
