@@ -9,14 +9,6 @@
         <source>Version:</source>
         <translation>እትም:</translation>
     </message>
-    <message>
-        <source>Deepin Image Viewer is a fashion &amp; smooth image manager.</source>
-        <translation>ዲፕኢን የ ምስል መመልከቻ ዘመናዊ &amp; ቀላል የ ምስል አስተዳዳሪ ነው</translation>
-    </message>
-    <message>
-        <source>It is featured with image management, image viewing and basic image editing.</source>
-        <translation>የ ምስል አስተዳዳሪ: ምስል መመልከቻ: እና መሰረታዊ የ ምስል ማረሚያ</translation>
-    </message>
 </context>
 <context>
     <name>AlbumBTContent</name>
@@ -255,10 +247,6 @@
         <source>Copy to clipboard</source>
         <translation>ወደ ቁራጭ ሰሌዳ ኮፒ ማድረጊያ</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>ወደ ቆሻሻ መጣያ</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>ከ አልበም ውስጥ ማስወገጃ</translation>
@@ -307,6 +295,10 @@
         <source>Add to new album</source>
         <translation>ወደ አዲስ አልበም መጨመሪያ</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>Importer</name>
@@ -341,8 +333,8 @@
         <translation>የ ተሻሻለበት ቀን</translation>
     </message>
     <message>
-        <source>Resolution</source>
-        <translation>ሪዞሊሽን</translation>
+        <source>Dimension</source>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>File size</source>
@@ -448,6 +440,13 @@
         <translation type="unfinished"/>
     </message>
 </context>
+<context>
+    <name>PrintPreviewDialog</name>
+    <message>
+        <source>Image Settings</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>QObject</name>
     <message>
@@ -547,10 +546,6 @@
         <source>Copy</source>
         <translation>ኮፒ</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>ወደ ቆሻሻ መጣያ</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>ከ አልበም ውስጥ ማስወገጃ</translation>
@@ -619,6 +614,10 @@
         <source>Display shortcuts</source>
         <translation>አቋራጭ ማሳያ</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>ShortcutEditor</name>
@@ -672,10 +671,6 @@
         <source>Copy</source>
         <translation>ኮፒ</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>ወደ ቆሻሻ መጣያ</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>ከ አልበም ውስጥ ማስወገጃ</translation>
@@ -785,10 +780,6 @@
         <source>Rotate clockwise</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>Throw to Trash</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Unfavorite</source>
         <translation type="unfinished"/>
@@ -797,6 +788,10 @@
         <source>Favorite</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>ThumbnailWidget</name>
@@ -804,6 +799,10 @@
         <source>No image files found</source>
         <translation>ምንም የ ምስል ፋይል አልተገኘም</translation>
     </message>
+    <message>
+        <source>Open Image</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>TimelineBTContent</name>
@@ -870,10 +869,6 @@
         <source>Copy to clipboard</source>
         <translation>ወደ ቁራጭ ሰሌዳ ኮፒ ማድረጊያ</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>ወደ ቆሻሻ መጣያ</translation>
-    </message>
     <message>
         <source>Favorite</source>
         <translation>የምወዳቸው</translation>
@@ -902,6 +897,10 @@
         <source>Image info</source>
         <translation>የ ምስል መረጃ</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>TitleFrame</name>
@@ -967,6 +966,10 @@
         <source>Dark theme</source>
         <translation>ጥቁር ገጽታ</translation>
     </message>
+    <message>
+        <source>Deepin Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>ViewPanel</name>
@@ -1006,10 +1009,6 @@
         <source>Copy to clipboard</source>
         <translation>ወደ ቁራጭ ሰሌዳ ኮፒ ማድረጊያ</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>ወደ ቆሻሻ መጣያ</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>ከ አልበም ውስጥ ማስወገጃ</translation>
@@ -1050,5 +1049,17 @@
         <source>Image info</source>
         <translation>የ ምስል መረጃ</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Open Image</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>All images</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 </TS>
\ No newline at end of file
