@@ -9,14 +9,6 @@
         <source>Version:</source>
         <translation>Versión:</translation>
     </message>
-    <message>
-        <source>Deepin Image Viewer is a fashion &amp; smooth image manager.</source>
-        <translation>El visor Deepin d&apos;imáxenes ye un xestor d&apos;imáxenes modernu y estable.</translation>
-    </message>
-    <message>
-        <source>It is featured with image management, image viewing and basic image editing.</source>
-        <translation>Vien con xestión, visión y edición básica de semeyes.</translation>
-    </message>
 </context>
 <context>
     <name>AlbumBTContent</name>
@@ -226,7 +218,7 @@
     <name>ImageView</name>
     <message>
         <source>This file contains multiple pages, please use Evince to view all pages.</source>
-        <translation type="unfinished"/>
+        <translation>Esti ficheru contién munches páxines, usa Evince pa veles toes.</translation>
     </message>
 </context>
 <context>
@@ -255,10 +247,6 @@
         <source>Copy to clipboard</source>
         <translation>Copiar al cartafueyu</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Tirar a la papelera</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Desaniciar del álbum</translation>
@@ -307,6 +295,10 @@
         <source>Add to new album</source>
         <translation>Amestar al álbum nuevu</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>Importer</name>
@@ -341,8 +333,8 @@
         <translation>Data de modificación</translation>
     </message>
     <message>
-        <source>Resolution</source>
-        <translation>Resolución</translation>
+        <source>Dimension</source>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>File size</source>
@@ -413,27 +405,27 @@
     </message>
     <message>
         <source>Fit page to image</source>
-        <translation type="unfinished"/>
+        <translation>Axustar páxina a la imaxe</translation>
     </message>
     <message>
         <source>Fit image to page</source>
-        <translation type="unfinished"/>
+        <translation>Axustar imaxe a la páxina</translation>
     </message>
     <message>
         <source>Scale to:</source>
-        <translation type="unfinished"/>
+        <translation>Escalar a:</translation>
     </message>
     <message>
         <source>Millimeters</source>
-        <translation type="unfinished"/>
+        <translation>Milímetros</translation>
     </message>
     <message>
         <source>Centimeters</source>
-        <translation type="unfinished"/>
+        <translation>Centímetros</translation>
     </message>
     <message>
         <source>Inches</source>
-        <translation type="unfinished"/>
+        <translation>Pulgaes</translation>
     </message>
     <message>
         <source>Image Position</source>
@@ -441,8 +433,15 @@
     </message>
     <message>
         <source>Scaling</source>
+        <translation>Escaláu</translation>
+    </message>
+    <message>
+        <source>Image Settings</source>
         <translation type="unfinished"/>
     </message>
+</context>
+<context>
+    <name>PrintPreviewDialog</name>
     <message>
         <source>Image Settings</source>
         <translation type="unfinished"/>
@@ -547,10 +546,6 @@
         <source>Copy</source>
         <translation>Copiar</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Tirar a la papelera</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Desaniciar del álbum</translation>
@@ -619,6 +614,10 @@
         <source>Display shortcuts</source>
         <translation>Amosar atayos</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>ShortcutEditor</name>
@@ -672,10 +671,6 @@
         <source>Copy</source>
         <translation>Copiar</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Tirar a la papelera</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Desaniciar del álbum</translation>
@@ -771,23 +766,19 @@
     </message>
     <message>
         <source>1:1 Size</source>
-        <translation type="unfinished"/>
+        <translation>Tamañu 1:1</translation>
     </message>
     <message>
         <source>Fit to window</source>
-        <translation type="unfinished"/>
+        <translation>Axustar a la ventana</translation>
     </message>
     <message>
         <source>Rotate counterclockwise</source>
-        <translation type="unfinished"/>
+        <translation>Voltiar a esquierda</translation>
     </message>
     <message>
         <source>Rotate clockwise</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Throw to Trash</source>
-        <translation type="unfinished"/>
+        <translation>Voltiar a drecha</translation>
     </message>
     <message>
         <source>Unfavorite</source>
@@ -797,6 +788,10 @@
         <source>Favorite</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>ThumbnailWidget</name>
@@ -804,6 +799,10 @@
         <source>No image files found</source>
         <translation>Nun s&apos;alcontraron imáxenes</translation>
     </message>
+    <message>
+        <source>Open Image</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>TimelineBTContent</name>
@@ -870,10 +869,6 @@
         <source>Copy to clipboard</source>
         <translation>Copiar al cartafueyu</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Tirar a la papelera</translation>
-    </message>
     <message>
         <source>Favorite</source>
         <translation>Favorita</translation>
@@ -902,6 +897,10 @@
         <source>Image info</source>
         <translation>Información d&apos;imaxe</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>TitleFrame</name>
@@ -967,6 +966,10 @@
         <source>Dark theme</source>
         <translation>Tema prietu</translation>
     </message>
+    <message>
+        <source>Deepin Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>ViewPanel</name>
@@ -1006,10 +1009,6 @@
         <source>Copy to clipboard</source>
         <translation>Copiar al cartafueyu</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Tirar a la papelera</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Desaniciar del álbum</translation>
@@ -1050,5 +1049,17 @@
         <source>Image info</source>
         <translation>información d&apos;imaxe</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Open Image</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>All images</source>
+        <translation>Toles imáxenes</translation>
+    </message>
 </context>
 </TS>
\ No newline at end of file
