@@ -9,14 +9,6 @@
         <source>Version:</source>
         <translation>Версия:</translation>
     </message>
-    <message>
-        <source>Deepin Image Viewer is a fashion &amp; smooth image manager.</source>
-        <translation>Deepin Преглед на изображения е модерен и лесен за работа мениджър на изображения</translation>
-    </message>
-    <message>
-        <source>It is featured with image management, image viewing and basic image editing.</source>
-        <translation>Предназначен е за управление на изображения, преглед на изображения и основни възможности за редактиране на изображение.</translation>
-    </message>
 </context>
 <context>
     <name>AlbumBTContent</name>
@@ -255,10 +247,6 @@
         <source>Copy to clipboard</source>
         <translation>Копиране в системния буфер</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Изпращане в кошчето</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Премахване от албума</translation>
@@ -307,6 +295,10 @@
         <source>Add to new album</source>
         <translation>Добави в нов албум</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Премахване</translation>
+    </message>
 </context>
 <context>
     <name>Importer</name>
@@ -341,8 +333,8 @@
         <translation>Дата на промяна</translation>
     </message>
     <message>
-        <source>Resolution</source>
-        <translation>Резолюция</translation>
+        <source>Dimension</source>
+        <translation>Размери</translation>
     </message>
     <message>
         <source>File size</source>
@@ -409,43 +401,50 @@
     <name>PrintOptionsPage</name>
     <message>
         <source>No scaling</source>
-        <translation type="unfinished"/>
+        <translation>Без мащабиране</translation>
     </message>
     <message>
         <source>Fit page to image</source>
-        <translation type="unfinished"/>
+        <translation>Оразмери страницата по картината</translation>
     </message>
     <message>
         <source>Fit image to page</source>
-        <translation type="unfinished"/>
+        <translation>Оразмери картината по страницата</translation>
     </message>
     <message>
         <source>Scale to:</source>
-        <translation type="unfinished"/>
+        <translation>Мащабирай по:</translation>
     </message>
     <message>
         <source>Millimeters</source>
-        <translation type="unfinished"/>
+        <translation>Милиметри</translation>
     </message>
     <message>
         <source>Centimeters</source>
-        <translation type="unfinished"/>
+        <translation>Сантиметри</translation>
     </message>
     <message>
         <source>Inches</source>
-        <translation type="unfinished"/>
+        <translation>Инчове</translation>
     </message>
     <message>
         <source>Image Position</source>
-        <translation type="unfinished"/>
+        <translation>Позиция на картината</translation>
     </message>
     <message>
         <source>Scaling</source>
-        <translation type="unfinished"/>
+        <translation>Мащабиране</translation>
     </message>
     <message>
         <source>Image Settings</source>
-        <translation type="unfinished"/>
+        <translation>Настройки на картината</translation>
+    </message>
+</context>
+<context>
+    <name>PrintPreviewDialog</name>
+    <message>
+        <source>Image Settings</source>
+        <translation>Настройки на картината</translation>
     </message>
 </context>
 <context>
@@ -547,10 +546,6 @@
         <source>Copy</source>
         <translation>Копиране</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Изпращане в кошчето</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Премахване от албума</translation>
@@ -619,6 +614,10 @@
         <source>Display shortcuts</source>
         <translation>Покажи клавишните комбинации</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Премахване</translation>
+    </message>
 </context>
 <context>
     <name>ShortcutEditor</name>
@@ -672,10 +671,6 @@
         <source>Copy</source>
         <translation>Копиране</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Изпращане в кошчето</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Премахване от албума</translation>
@@ -785,10 +780,6 @@
         <source>Rotate clockwise</source>
         <translation>Завъртане по часовниковата стрелка</translation>
     </message>
-    <message>
-        <source>Throw to Trash</source>
-        <translation>Изпращане в кошчето</translation>
-    </message>
     <message>
         <source>Unfavorite</source>
         <translation>Премахване от Любими</translation>
@@ -797,6 +788,10 @@
         <source>Favorite</source>
         <translation>Любими</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Премахване</translation>
+    </message>
 </context>
 <context>
     <name>ThumbnailWidget</name>
@@ -804,6 +799,10 @@
         <source>No image files found</source>
         <translation>Няма намерени изображения</translation>
     </message>
+    <message>
+        <source>Open Image</source>
+        <translation>Отваряне на изображение</translation>
+    </message>
 </context>
 <context>
     <name>TimelineBTContent</name>
@@ -870,10 +869,6 @@
         <source>Copy to clipboard</source>
         <translation>Копиране в системния буфер</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Изпращане в кошчето</translation>
-    </message>
     <message>
         <source>Favorite</source>
         <translation>Любими</translation>
@@ -902,6 +897,10 @@
         <source>Image info</source>
         <translation>Информация за изображението</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Премахване</translation>
+    </message>
 </context>
 <context>
     <name>TitleFrame</name>
@@ -967,6 +966,10 @@
         <source>Dark theme</source>
         <translation>Тъмна тема</translation>
     </message>
+    <message>
+        <source>Deepin Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
+        <translation>Deepin преглед на изображения е инструмент за преглед на изображения с моден интерфейс и гладко изпълнение.</translation>
+    </message>
 </context>
 <context>
     <name>ViewPanel</name>
@@ -1006,10 +1009,6 @@
         <source>Copy to clipboard</source>
         <translation>Копиране в системния буфер</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Изпращане в кошчето</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Премахване от албума</translation>
@@ -1050,5 +1049,17 @@
         <source>Image info</source>
         <translation>Информация за изображението</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Премахване</translation>
+    </message>
+    <message>
+        <source>Open Image</source>
+        <translation>Отваряне на изображение</translation>
+    </message>
+    <message>
+        <source>All images</source>
+        <translation>Всички изображения</translation>
+    </message>
 </context>
 </TS>
\ No newline at end of file
