@@ -9,14 +9,6 @@
         <source>Version:</source>
         <translation>Versió:</translation>
     </message>
-    <message>
-        <source>Deepin Image Viewer is a fashion &amp; smooth image manager.</source>
-        <translation>El Visualitzador d&apos;imatges del Deepin és un gestor d&apos;imatges modern i fàcil d&apos;usar.</translation>
-    </message>
-    <message>
-        <source>It is featured with image management, image viewing and basic image editing.</source>
-        <translation>Té les funcions de gestió, visualització i edició bàsica d&apos;imatges.</translation>
-    </message>
 </context>
 <context>
     <name>AlbumBTContent</name>
@@ -255,10 +247,6 @@
         <source>Copy to clipboard</source>
         <translation>Copia al porta-retalls</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Llença a la paperera</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Elimina de l&apos;àlbum</translation>
@@ -307,6 +295,10 @@
         <source>Add to new album</source>
         <translation>Afegeix a un àlbum nou</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Elimina</translation>
+    </message>
 </context>
 <context>
     <name>Importer</name>
@@ -341,8 +333,8 @@
         <translation>Data de modificació</translation>
     </message>
     <message>
-        <source>Resolution</source>
-        <translation>Resolució</translation>
+        <source>Dimension</source>
+        <translation>Dimensió</translation>
     </message>
     <message>
         <source>File size</source>
@@ -448,6 +440,13 @@
         <translation>Configuració de la imatge</translation>
     </message>
 </context>
+<context>
+    <name>PrintPreviewDialog</name>
+    <message>
+        <source>Image Settings</source>
+        <translation>Configuració de la imatge</translation>
+    </message>
+</context>
 <context>
     <name>QObject</name>
     <message>
@@ -547,10 +546,6 @@
         <source>Copy</source>
         <translation>Copia</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Llença a la paperera</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Elimina de l&apos;àlbum</translation>
@@ -619,6 +614,10 @@
         <source>Display shortcuts</source>
         <translation>Mostra les dreceres</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Elimina</translation>
+    </message>
 </context>
 <context>
     <name>ShortcutEditor</name>
@@ -672,10 +671,6 @@
         <source>Copy</source>
         <translation>Copia</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Llença a la paperera</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Elimina de l&apos;àlbum</translation>
@@ -785,10 +780,6 @@
         <source>Rotate clockwise</source>
         <translation>Gira a la dreta</translation>
     </message>
-    <message>
-        <source>Throw to Trash</source>
-        <translation>Llença a la paperera</translation>
-    </message>
     <message>
         <source>Unfavorite</source>
         <translation>No favorit</translation>
@@ -797,6 +788,10 @@
         <source>Favorite</source>
         <translation>Favorit</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Elimina</translation>
+    </message>
 </context>
 <context>
     <name>ThumbnailWidget</name>
@@ -804,6 +799,10 @@
         <source>No image files found</source>
         <translation>No s&apos;ha trobat cap fitxer d&apos;imatge.</translation>
     </message>
+    <message>
+        <source>Open Image</source>
+        <translation>Obre la imatge</translation>
+    </message>
 </context>
 <context>
     <name>TimelineBTContent</name>
@@ -870,10 +869,6 @@
         <source>Copy to clipboard</source>
         <translation>Copia al porta-retalls</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Llença a la paperera</translation>
-    </message>
     <message>
         <source>Favorite</source>
         <translation>Favorit</translation>
@@ -902,6 +897,10 @@
         <source>Image info</source>
         <translation>Informació de la imatge</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Elimina</translation>
+    </message>
 </context>
 <context>
     <name>TitleFrame</name>
@@ -967,6 +966,10 @@
         <source>Dark theme</source>
         <translation>Tema fosc</translation>
     </message>
+    <message>
+        <source>Deepin Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
+        <translation>El Visualitzador d&apos;imatges del Deepin és una eina de visualitzador d&apos;imatges amb una interfície moderna i un rendiment eficient.</translation>
+    </message>
 </context>
 <context>
     <name>ViewPanel</name>
@@ -1006,10 +1009,6 @@
         <source>Copy to clipboard</source>
         <translation>Copia al porta-retalls</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Llença a la paperera</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Elimina de l&apos;àlbum</translation>
@@ -1050,5 +1049,17 @@
         <source>Image info</source>
         <translation>Informació de la imatge</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Elimina</translation>
+    </message>
+    <message>
+        <source>Open Image</source>
+        <translation>Obre la imatge</translation>
+    </message>
+    <message>
+        <source>All images</source>
+        <translation>Totes les imatges</translation>
+    </message>
 </context>
 </TS>
\ No newline at end of file
