@@ -9,14 +9,6 @@
         <source>Version:</source>
         <translation>Version:</translation>
     </message>
-    <message>
-        <source>Deepin Image Viewer is a fashion &amp; smooth image manager.</source>
-        <translation>Deepin billedfremviser er en moderigtig og glat billedhåndtering.</translation>
-    </message>
-    <message>
-        <source>It is featured with image management, image viewing and basic image editing.</source>
-        <translation>Dens faciliteter er billedhåndtering, billedvisning og grundlæggende billedredigering.</translation>
-    </message>
 </context>
 <context>
     <name>AlbumBTContent</name>
@@ -255,10 +247,6 @@
         <source>Copy to clipboard</source>
         <translation>Kopiér til udklipsholder</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Smid i papirkurv</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Fjern fra album</translation>
@@ -307,6 +295,10 @@
         <source>Add to new album</source>
         <translation>Tilføj til nyt album</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Slet</translation>
+    </message>
 </context>
 <context>
     <name>Importer</name>
@@ -341,8 +333,8 @@
         <translation>Ændringsdato</translation>
     </message>
     <message>
-        <source>Resolution</source>
-        <translation>Opløsning</translation>
+        <source>Dimension</source>
+        <translation>Dimension</translation>
     </message>
     <message>
         <source>File size</source>
@@ -448,6 +440,13 @@
         <translation>Indstillinger for billede</translation>
     </message>
 </context>
+<context>
+    <name>PrintPreviewDialog</name>
+    <message>
+        <source>Image Settings</source>
+        <translation>Billedindstillinger</translation>
+    </message>
+</context>
 <context>
     <name>QObject</name>
     <message>
@@ -547,10 +546,6 @@
         <source>Copy</source>
         <translation>Kopiér</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Smid i papirkurv</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Fjern fra album</translation>
@@ -619,6 +614,10 @@
         <source>Display shortcuts</source>
         <translation>Vis genveje</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Slet</translation>
+    </message>
 </context>
 <context>
     <name>ShortcutEditor</name>
@@ -672,10 +671,6 @@
         <source>Copy</source>
         <translation>Kopiér</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Smid i papirkurv</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Fjern fra album</translation>
@@ -785,10 +780,6 @@
         <source>Rotate clockwise</source>
         <translation>Rotér med uret</translation>
     </message>
-    <message>
-        <source>Throw to Trash</source>
-        <translation>Smid i papirkurv</translation>
-    </message>
     <message>
         <source>Unfavorite</source>
         <translation>Fjern fra favorit</translation>
@@ -797,6 +788,10 @@
         <source>Favorite</source>
         <translation>Sæt som favorit</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Slet</translation>
+    </message>
 </context>
 <context>
     <name>ThumbnailWidget</name>
@@ -804,6 +799,10 @@
         <source>No image files found</source>
         <translation>Ingen billedfiler fundet</translation>
     </message>
+    <message>
+        <source>Open Image</source>
+        <translation>Åbn billede</translation>
+    </message>
 </context>
 <context>
     <name>TimelineBTContent</name>
@@ -870,10 +869,6 @@
         <source>Copy to clipboard</source>
         <translation>Kopiér til udklipsholder</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Smid i papirkurv</translation>
-    </message>
     <message>
         <source>Favorite</source>
         <translation>Sæt som favorit</translation>
@@ -902,6 +897,10 @@
         <source>Image info</source>
         <translation>Billedinfo</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Slet</translation>
+    </message>
 </context>
 <context>
     <name>TitleFrame</name>
@@ -967,6 +966,10 @@
         <source>Dark theme</source>
         <translation>Mørkt tema</translation>
     </message>
+    <message>
+        <source>Deepin Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
+        <translation>Deepin billedfremviser er et billedfremviserværktøj med moderigtig brugerflade og glat ydelse.</translation>
+    </message>
 </context>
 <context>
     <name>ViewPanel</name>
@@ -1006,10 +1009,6 @@
         <source>Copy to clipboard</source>
         <translation>Kopiér til udklipsholder</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Smid i papirkurv</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Fjern fra album</translation>
@@ -1050,5 +1049,17 @@
         <source>Image info</source>
         <translation>Billedinfo</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Slet</translation>
+    </message>
+    <message>
+        <source>Open Image</source>
+        <translation>Åbn billede</translation>
+    </message>
+    <message>
+        <source>All images</source>
+        <translation>Alle billeder</translation>
+    </message>
 </context>
 </TS>
\ No newline at end of file
