@@ -9,14 +9,6 @@
         <source>Version:</source>
         <translation>Version:</translation>
     </message>
-    <message>
-        <source>Deepin Image Viewer is a fashion &amp; smooth image manager.</source>
-        <translation>Der Deepin Bildbetrachter ist eine elegante &amp; schnelle Bildverwaltung.</translation>
-    </message>
-    <message>
-        <source>It is featured with image management, image viewing and basic image editing.</source>
-        <translation>Er bietet Bildverwaltung, Bildbetrachtung und einfache Bildbearbeitung.</translation>
-    </message>
 </context>
 <context>
     <name>AlbumBTContent</name>
@@ -255,10 +247,6 @@
         <source>Copy to clipboard</source>
         <translation>In Zwischenablage kopieren</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>In Papierkorb werfen</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Aus Album entfernen</translation>
@@ -307,6 +295,10 @@
         <source>Add to new album</source>
         <translation>Zu neuem Album hinzufügen</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Löschen</translation>
+    </message>
 </context>
 <context>
     <name>Importer</name>
@@ -341,8 +333,8 @@
         <translation>Änderungsdatum</translation>
     </message>
     <message>
-        <source>Resolution</source>
-        <translation>Auflösung</translation>
+        <source>Dimension</source>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>File size</source>
@@ -448,6 +440,13 @@
         <translation>Bildeigenschaften</translation>
     </message>
 </context>
+<context>
+    <name>PrintPreviewDialog</name>
+    <message>
+        <source>Image Settings</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>QObject</name>
     <message>
@@ -547,10 +546,6 @@
         <source>Copy</source>
         <translation>Kopieren</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>In Papierkorb werfen</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Aus Album entfernen</translation>
@@ -619,6 +614,10 @@
         <source>Display shortcuts</source>
         <translation>Tastenkürzel anzeigen</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Löschen</translation>
+    </message>
 </context>
 <context>
     <name>ShortcutEditor</name>
@@ -672,10 +671,6 @@
         <source>Copy</source>
         <translation>Kopieren</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>In Papierkorb werfen</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Aus Album entfernen</translation>
@@ -785,10 +780,6 @@
         <source>Rotate clockwise</source>
         <translation>Im Uhrzeigersinn drehen</translation>
     </message>
-    <message>
-        <source>Throw to Trash</source>
-        <translation>In den Papierkorb ablegen</translation>
-    </message>
     <message>
         <source>Unfavorite</source>
         <translation>Favorit entfernen</translation>
@@ -797,6 +788,10 @@
         <source>Favorite</source>
         <translation>Favorit hinzufügen</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Löschen</translation>
+    </message>
 </context>
 <context>
     <name>ThumbnailWidget</name>
@@ -804,6 +799,10 @@
         <source>No image files found</source>
         <translation>Keine Bilddateien gefunden</translation>
     </message>
+    <message>
+        <source>Open Image</source>
+        <translation>Bild öffnen</translation>
+    </message>
 </context>
 <context>
     <name>TimelineBTContent</name>
@@ -870,10 +869,6 @@
         <source>Copy to clipboard</source>
         <translation>In Zwischenablage kopieren</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>In Papierkorb werfen</translation>
-    </message>
     <message>
         <source>Favorite</source>
         <translation>Favorit</translation>
@@ -902,6 +897,10 @@
         <source>Image info</source>
         <translation>Bildinformation</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Löschen</translation>
+    </message>
 </context>
 <context>
     <name>TitleFrame</name>
@@ -967,6 +966,10 @@
         <source>Dark theme</source>
         <translation>Dunkles Design</translation>
     </message>
+    <message>
+        <source>Deepin Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
+        <translation>Der Deepin Bildbetrachter ist eine elegante &amp; schnelle Bildverwaltung.</translation>
+    </message>
 </context>
 <context>
     <name>ViewPanel</name>
@@ -1006,10 +1009,6 @@
         <source>Copy to clipboard</source>
         <translation>In Zwischenablage kopieren</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>In Papierkorb werfen</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Aus Album entfernen</translation>
@@ -1050,5 +1049,17 @@
         <source>Image info</source>
         <translation>Bildinformation</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Löschen</translation>
+    </message>
+    <message>
+        <source>Open Image</source>
+        <translation>Bild öffnen</translation>
+    </message>
+    <message>
+        <source>All images</source>
+        <translation>Alle Bilder</translation>
+    </message>
 </context>
 </TS>
\ No newline at end of file
