@@ -9,14 +9,6 @@
         <source>Version:</source>
         <translation>Versión:</translation>
     </message>
-    <message>
-        <source>Deepin Image Viewer is a fashion &amp; smooth image manager.</source>
-        <translation>Visor de imágenes Deepin es un bonito y suave organizador de imágenes.</translation>
-    </message>
-    <message>
-        <source>It is featured with image management, image viewing and basic image editing.</source>
-        <translation>Destaca con la organización, visualización y edición básica de imágenes.</translation>
-    </message>
 </context>
 <context>
     <name>AlbumBTContent</name>
@@ -125,7 +117,7 @@
     </message>
     <message>
         <source>Slide show</source>
-        <translation>Mostrar presentación</translation>
+        <translation>Presentar en diapositivas</translation>
     </message>
     <message>
         <source>Rename</source>
@@ -241,7 +233,7 @@
     </message>
     <message>
         <source>Slide show</source>
-        <translation>Mostrar presentación</translation>
+        <translation>Presentar en diapositivas</translation>
     </message>
     <message>
         <source>Print</source>
@@ -255,10 +247,6 @@
         <source>Copy to clipboard</source>
         <translation>Copiar al portapapeles</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Mover a la papelera</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Eliminar del álbum</translation>
@@ -307,6 +295,10 @@
         <source>Add to new album</source>
         <translation>Añadir a nuevo álbum</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Eliminar</translation>
+    </message>
 </context>
 <context>
     <name>Importer</name>
@@ -341,8 +333,8 @@
         <translation>Fecha modificada</translation>
     </message>
     <message>
-        <source>Resolution</source>
-        <translation>Resolución</translation>
+        <source>Dimension</source>
+        <translation>Dimensión</translation>
     </message>
     <message>
         <source>File size</source>
@@ -448,6 +440,13 @@
         <translation>Ajustes de la imagen</translation>
     </message>
 </context>
+<context>
+    <name>PrintPreviewDialog</name>
+    <message>
+        <source>Image Settings</source>
+        <translation>Ajustes de imagen</translation>
+    </message>
+</context>
 <context>
     <name>QObject</name>
     <message>
@@ -537,7 +536,7 @@
     </message>
     <message>
         <source>Slide show</source>
-        <translation>Mostrar presentación</translation>
+        <translation>Presentar en diapositivas</translation>
     </message>
     <message>
         <source>End show</source>
@@ -547,10 +546,6 @@
         <source>Copy</source>
         <translation>Copiar</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Mover a la papelera</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Eliminar del álbum</translation>
@@ -619,6 +614,10 @@
         <source>Display shortcuts</source>
         <translation>Mostrar atajos</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Eliminar</translation>
+    </message>
 </context>
 <context>
     <name>ShortcutEditor</name>
@@ -658,7 +657,7 @@
     </message>
     <message>
         <source>Slide show</source>
-        <translation>Mostrar presentación</translation>
+        <translation>Presentar en diapositivas</translation>
     </message>
     <message>
         <source>End show</source>
@@ -672,10 +671,6 @@
         <source>Copy</source>
         <translation>Copiar</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Mover a la papelera</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Remover del álbum</translation>
@@ -736,7 +731,7 @@
     <name>SlideshowFrame</name>
     <message>
         <source>Slide Settings</source>
-        <translation>Configuración de la presentación</translation>
+        <translation>Presentar en diapositivas</translation>
     </message>
     <message>
         <source>Switch effect</source>
@@ -785,10 +780,6 @@
         <source>Rotate clockwise</source>
         <translation>Girar hacia la derecha</translation>
     </message>
-    <message>
-        <source>Throw to Trash</source>
-        <translation>Mover a la papelera</translation>
-    </message>
     <message>
         <source>Unfavorite</source>
         <translation>No destacar</translation>
@@ -797,6 +788,10 @@
         <source>Favorite</source>
         <translation>Favorito</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Eliminar</translation>
+    </message>
 </context>
 <context>
     <name>ThumbnailWidget</name>
@@ -804,6 +799,10 @@
         <source>No image files found</source>
         <translation>No se econtraron archivos de imágen</translation>
     </message>
+    <message>
+        <source>Open Image</source>
+        <translation>Abrir imagen</translation>
+    </message>
 </context>
 <context>
     <name>TimelineBTContent</name>
@@ -856,7 +855,7 @@
     </message>
     <message>
         <source>Slide show</source>
-        <translation>Mostrar presentación</translation>
+        <translation>Presentar en diapositivas</translation>
     </message>
     <message>
         <source>Print</source>
@@ -870,10 +869,6 @@
         <source>Copy to clipboard</source>
         <translation>Copiar al portapapeles</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Mover a la papelera</translation>
-    </message>
     <message>
         <source>Favorite</source>
         <translation>Destacar</translation>
@@ -902,6 +897,10 @@
         <source>Image info</source>
         <translation>Información de imagen</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Eliminar</translation>
+    </message>
 </context>
 <context>
     <name>TitleFrame</name>
@@ -967,6 +966,10 @@
         <source>Dark theme</source>
         <translation>Tema oscuro</translation>
     </message>
+    <message>
+        <source>Deepin Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
+        <translation>El visor de imágenes deepin es una herramienta de visualización de imágenes con una interfaz moderna y rápida.</translation>
+    </message>
 </context>
 <context>
     <name>ViewPanel</name>
@@ -992,7 +995,7 @@
     </message>
     <message>
         <source>Slide show</source>
-        <translation>Mostrar presentación</translation>
+        <translation>Presentar en diapositivas</translation>
     </message>
     <message>
         <source>Print</source>
@@ -1006,10 +1009,6 @@
         <source>Copy to clipboard</source>
         <translation>Copiar al portapapeles</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Mover a la papelera</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Remover del álbum</translation>
@@ -1050,5 +1049,17 @@
         <source>Image info</source>
         <translation>Información de imagen</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Eliminar</translation>
+    </message>
+    <message>
+        <source>Open Image</source>
+        <translation>Abrir imagen</translation>
+    </message>
+    <message>
+        <source>All images</source>
+        <translation>Todas las imágenes</translation>
+    </message>
 </context>
 </TS>
\ No newline at end of file
