@@ -9,14 +9,6 @@
         <source>Version:</source>
         <translation>Version: </translation>
     </message>
-    <message>
-        <source>Deepin Image Viewer is a fashion &amp; smooth image manager.</source>
-        <translation>Deepin Image est un pratique gestionnaire d&apos;images.</translation>
-    </message>
-    <message>
-        <source>It is featured with image management, image viewing and basic image editing.</source>
-        <translation>C&apos;est un gestionnaire, visualiseur et éditeur d&apos;images.</translation>
-    </message>
 </context>
 <context>
     <name>AlbumBTContent</name>
@@ -255,10 +247,6 @@
         <source>Copy to clipboard</source>
         <translation>Copier dans le presse-papier</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Envoyer dans la corbeille</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Enlever de l&apos;album</translation>
@@ -307,6 +295,10 @@
         <source>Add to new album</source>
         <translation>Ajouter au nouvel album</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Supprimer</translation>
+    </message>
 </context>
 <context>
     <name>Importer</name>
@@ -341,8 +333,8 @@
         <translation>Date de modification</translation>
     </message>
     <message>
-        <source>Resolution</source>
-        <translation>Résolution </translation>
+        <source>Dimension</source>
+        <translation>Dimension</translation>
     </message>
     <message>
         <source>File size</source>
@@ -448,6 +440,13 @@
         <translation>Paramètres de l&apos;image</translation>
     </message>
 </context>
+<context>
+    <name>PrintPreviewDialog</name>
+    <message>
+        <source>Image Settings</source>
+        <translation>Paramètres d&apos;image</translation>
+    </message>
+</context>
 <context>
     <name>QObject</name>
     <message>
@@ -547,10 +546,6 @@
         <source>Copy</source>
         <translation>Copier</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Envoyer dans la corbeille</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Enlever de l&apos;album</translation>
@@ -619,6 +614,10 @@
         <source>Display shortcuts</source>
         <translation>Afficher les raccourcis</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Supprimer</translation>
+    </message>
 </context>
 <context>
     <name>ShortcutEditor</name>
@@ -672,10 +671,6 @@
         <source>Copy</source>
         <translation>Copier</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Envoyer dans la corbeille</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Enlever de l&apos;album</translation>
@@ -785,10 +780,6 @@
         <source>Rotate clockwise</source>
         <translation>Tourner dans le sens des aiguilles d&apos;une montre</translation>
     </message>
-    <message>
-        <source>Throw to Trash</source>
-        <translation>Envoyer dans la corbeille</translation>
-    </message>
     <message>
         <source>Unfavorite</source>
         <translation>Retirer des favoris</translation>
@@ -797,6 +788,10 @@
         <source>Favorite</source>
         <translation>Favoris </translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Supprimer</translation>
+    </message>
 </context>
 <context>
     <name>ThumbnailWidget</name>
@@ -804,6 +799,10 @@
         <source>No image files found</source>
         <translation>Pas d&apos;images trouvées</translation>
     </message>
+    <message>
+        <source>Open Image</source>
+        <translation>Ouvrir une image</translation>
+    </message>
 </context>
 <context>
     <name>TimelineBTContent</name>
@@ -870,10 +869,6 @@
         <source>Copy to clipboard</source>
         <translation>Copier dans le presse-papier</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Envoyer dans la corbeille</translation>
-    </message>
     <message>
         <source>Favorite</source>
         <translation>Favoris </translation>
@@ -902,6 +897,10 @@
         <source>Image info</source>
         <translation>Image infos</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Supprimer</translation>
+    </message>
 </context>
 <context>
     <name>TitleFrame</name>
@@ -967,6 +966,10 @@
         <source>Dark theme</source>
         <translation>Thème sombre</translation>
     </message>
+    <message>
+        <source>Deepin Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
+        <translation>Visionneur d&apos;images Deepin est un outil de visionnage d&apos;image avec une interface simple et des performances accrue.</translation>
+    </message>
 </context>
 <context>
     <name>ViewPanel</name>
@@ -1006,10 +1009,6 @@
         <source>Copy to clipboard</source>
         <translation>Copier dans le presse-papier</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Envoyer dans la corbeille</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Enlever de l&apos;album</translation>
@@ -1050,5 +1049,17 @@
         <source>Image info</source>
         <translation>Image infos</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Supprimer</translation>
+    </message>
+    <message>
+        <source>Open Image</source>
+        <translation>Ouvrir une image</translation>
+    </message>
+    <message>
+        <source>All images</source>
+        <translation>Toutes les images </translation>
+    </message>
 </context>
 </TS>
\ No newline at end of file
