@@ -9,14 +9,6 @@
         <source>Version:</source>
         <translation>Versión:</translation>
     </message>
-    <message>
-        <source>Deepin Image Viewer is a fashion &amp; smooth image manager.</source>
-        <translation>O visualizador de imaxes é un xestor de imaxes moderno e fluído.</translation>
-    </message>
-    <message>
-        <source>It is featured with image management, image viewing and basic image editing.</source>
-        <translation>Ten como características a xestión, visualización e a edición básica de imaxes.</translation>
-    </message>
 </context>
 <context>
     <name>AlbumBTContent</name>
@@ -226,7 +218,7 @@
     <name>ImageView</name>
     <message>
         <source>This file contains multiple pages, please use Evince to view all pages.</source>
-        <translation type="unfinished"/>
+        <translation>Este ficheiro contén varias páxinas, por favor emprega o Evince para velas todas.</translation>
     </message>
 </context>
 <context>
@@ -255,21 +247,17 @@
         <source>Copy to clipboard</source>
         <translation>Copiar no portarretallos</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Enviar ao lixo</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Eliminar do álbum</translation>
     </message>
     <message>
         <source>Favorite</source>
-        <translation>Poñer en favoritas</translation>
+        <translation>Poñer nas favoritas</translation>
     </message>
     <message>
         <source>Unfavorite</source>
-        <translation>Quitar de favoritas</translation>
+        <translation>Quitar das favoritas</translation>
     </message>
     <message>
         <source>Rotate clockwise</source>
@@ -307,6 +295,10 @@
         <source>Add to new album</source>
         <translation>Engadir a un novo álbum</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>Importer</name>
@@ -341,8 +333,8 @@
         <translation>Data da modificación</translation>
     </message>
     <message>
-        <source>Resolution</source>
-        <translation>Resolución</translation>
+        <source>Dimension</source>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>File size</source>
@@ -409,40 +401,47 @@
     <name>PrintOptionsPage</name>
     <message>
         <source>No scaling</source>
-        <translation type="unfinished"/>
+        <translation>Non escalar</translation>
     </message>
     <message>
         <source>Fit page to image</source>
-        <translation type="unfinished"/>
+        <translation>Axustar páxina á imaxe</translation>
     </message>
     <message>
         <source>Fit image to page</source>
-        <translation type="unfinished"/>
+        <translation>Axustar imaxe á páxina</translation>
     </message>
     <message>
         <source>Scale to:</source>
-        <translation type="unfinished"/>
+        <translation>Escalar a:</translation>
     </message>
     <message>
         <source>Millimeters</source>
-        <translation type="unfinished"/>
+        <translation>Milímetros</translation>
     </message>
     <message>
         <source>Centimeters</source>
-        <translation type="unfinished"/>
+        <translation>Centímetros</translation>
     </message>
     <message>
         <source>Inches</source>
-        <translation type="unfinished"/>
+        <translation>Polgadas</translation>
     </message>
     <message>
         <source>Image Position</source>
-        <translation type="unfinished"/>
+        <translation>Posición da imaxe</translation>
     </message>
     <message>
         <source>Scaling</source>
-        <translation type="unfinished"/>
+        <translation>Escalando</translation>
     </message>
+    <message>
+        <source>Image Settings</source>
+        <translation>Axustes da imaxe</translation>
+    </message>
+</context>
+<context>
+    <name>PrintPreviewDialog</name>
     <message>
         <source>Image Settings</source>
         <translation type="unfinished"/>
@@ -547,21 +546,17 @@
         <source>Copy</source>
         <translation>Copiar</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Enviar ao lixo</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Eliminar do álbum</translation>
     </message>
     <message>
         <source>Favorite</source>
-        <translation>Poñer en favoritas</translation>
+        <translation>Poñer nas favoritas</translation>
     </message>
     <message>
         <source>Unfavorite</source>
-        <translation>Quitar de favoritas</translation>
+        <translation>Quitar das favoritas</translation>
     </message>
     <message>
         <source>Rotate clockwise</source>
@@ -619,6 +614,10 @@
         <source>Display shortcuts</source>
         <translation>Amosar atallos</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>ShortcutEditor</name>
@@ -672,21 +671,17 @@
         <source>Copy</source>
         <translation>Copiar</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Enviar ao lixo</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Eliminar do álbum</translation>
     </message>
     <message>
         <source>Favorite</source>
-        <translation>Poñer en favoritas</translation>
+        <translation>Poñer nas favoritas</translation>
     </message>
     <message>
         <source>Unfavorite</source>
-        <translation>Quitar de favoritas</translation>
+        <translation>Quitar das favoritas</translation>
     </message>
     <message>
         <source>Rotate clockwise</source>
@@ -771,30 +766,30 @@
     </message>
     <message>
         <source>1:1 Size</source>
-        <translation type="unfinished"/>
+        <translation>Tamaño 1:1</translation>
     </message>
     <message>
         <source>Fit to window</source>
-        <translation type="unfinished"/>
+        <translation>Encaixar á xanela</translation>
     </message>
     <message>
         <source>Rotate counterclockwise</source>
-        <translation type="unfinished"/>
+        <translation>Rotar á esquerda</translation>
     </message>
     <message>
         <source>Rotate clockwise</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Throw to Trash</source>
-        <translation type="unfinished"/>
+        <translation>Rotar á dereita</translation>
     </message>
     <message>
         <source>Unfavorite</source>
-        <translation type="unfinished"/>
+        <translation>Quitar das favoritas</translation>
     </message>
     <message>
         <source>Favorite</source>
+        <translation>Poñer nas favoritas</translation>
+    </message>
+    <message>
+        <source>Delete</source>
         <translation type="unfinished"/>
     </message>
 </context>
@@ -804,6 +799,10 @@
         <source>No image files found</source>
         <translation>Non se atoparon ficheiros de imaxe</translation>
     </message>
+    <message>
+        <source>Open Image</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>TimelineBTContent</name>
@@ -870,17 +869,13 @@
         <source>Copy to clipboard</source>
         <translation>Copiar no portarretallos</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Enviar ao lixo</translation>
-    </message>
     <message>
         <source>Favorite</source>
-        <translation>Poñer en favoritas</translation>
+        <translation>Poñer nas favoritas</translation>
     </message>
     <message>
         <source>Unfavorite</source>
-        <translation>Quitar de favoritas</translation>
+        <translation>Quitar das favoritas</translation>
     </message>
     <message>
         <source>Rotate clockwise</source>
@@ -902,6 +897,10 @@
         <source>Image info</source>
         <translation>Información da imaxe</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>TitleFrame</name>
@@ -957,14 +956,18 @@
     </message>
     <message>
         <source>Deepin Image Viewer is a fashion &amp; smooth image manager.</source>
-        <translation type="unfinished"/>
+        <translation>O visualizador de imaxes é un xestor de imaxes moderno e fluído.</translation>
     </message>
     <message>
         <source>It is featured with image management, image viewing and basic image editing.</source>
-        <translation type="unfinished"/>
+        <translation>Ten como características a xestión, visualización e a edición básica de imaxes.</translation>
     </message>
     <message>
         <source>Dark theme</source>
+        <translation>Tema escuro</translation>
+    </message>
+    <message>
+        <source>Deepin Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
         <translation type="unfinished"/>
     </message>
 </context>
@@ -1006,21 +1009,17 @@
         <source>Copy to clipboard</source>
         <translation>Copiar no portarretallos</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Enviar ao lixo</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Eliminar do álbum</translation>
     </message>
     <message>
         <source>Favorite</source>
-        <translation>Poñer en favoritas</translation>
+        <translation>Poñer nas favoritas</translation>
     </message>
     <message>
         <source>Unfavorite</source>
-        <translation>Quitar de favoritas</translation>
+        <translation>Quitar das favoritas</translation>
     </message>
     <message>
         <source>Show navigation window</source>
@@ -1050,5 +1049,17 @@
         <source>Image info</source>
         <translation>Información da imaxe</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Open Image</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>All images</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 </TS>
\ No newline at end of file
