@@ -9,14 +9,6 @@
         <source>Version:</source>
         <translation>Inačica:</translation>
     </message>
-    <message>
-        <source>Deepin Image Viewer is a fashion &amp; smooth image manager.</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>It is featured with image management, image viewing and basic image editing.</source>
-        <translation>Dolazi sa upravljanjem slikama, pregledom slika i osnovnim uređivanjem slika.</translation>
-    </message>
 </context>
 <context>
     <name>AlbumBTContent</name>
@@ -255,10 +247,6 @@
         <source>Copy to clipboard</source>
         <translation>Kopiraj u međuspremnik</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Baci u smeće</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Ukloni iz albuma</translation>
@@ -307,6 +295,10 @@
         <source>Add to new album</source>
         <translation>Dodaj u novi album</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>Importer</name>
@@ -341,8 +333,8 @@
         <translation>Nadnevak izmjene</translation>
     </message>
     <message>
-        <source>Resolution</source>
-        <translation>Razlučivost</translation>
+        <source>Dimension</source>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>File size</source>
@@ -448,6 +440,13 @@
         <translation type="unfinished"/>
     </message>
 </context>
+<context>
+    <name>PrintPreviewDialog</name>
+    <message>
+        <source>Image Settings</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>QObject</name>
     <message>
@@ -547,10 +546,6 @@
         <source>Copy</source>
         <translation>Kopiraj</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Baci u smeće</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Ukloni iz albuma</translation>
@@ -619,6 +614,10 @@
         <source>Display shortcuts</source>
         <translation>Prikaži prečace</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>ShortcutEditor</name>
@@ -672,10 +671,6 @@
         <source>Copy</source>
         <translation>Kopiraj</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Baci u smeće</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Ukloni iz albuma</translation>
@@ -785,10 +780,6 @@
         <source>Rotate clockwise</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>Throw to Trash</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Unfavorite</source>
         <translation type="unfinished"/>
@@ -797,6 +788,10 @@
         <source>Favorite</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>ThumbnailWidget</name>
@@ -804,6 +799,10 @@
         <source>No image files found</source>
         <translation>NIje pronađena nijedna slikovna datoteka</translation>
     </message>
+    <message>
+        <source>Open Image</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>TimelineBTContent</name>
@@ -870,10 +869,6 @@
         <source>Copy to clipboard</source>
         <translation>Kopiraj u međuspremnik</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Baci u smeće</translation>
-    </message>
     <message>
         <source>Favorite</source>
         <translation>Omiljeni</translation>
@@ -902,6 +897,10 @@
         <source>Image info</source>
         <translation>Informacija o slici</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>TitleFrame</name>
@@ -967,6 +966,10 @@
         <source>Dark theme</source>
         <translation>Tamna tema</translation>
     </message>
+    <message>
+        <source>Deepin Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>ViewPanel</name>
@@ -1006,10 +1009,6 @@
         <source>Copy to clipboard</source>
         <translation>Kopiraj u međuspremnik</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Baci u smeće</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Ukloni iz albuma</translation>
@@ -1050,5 +1049,17 @@
         <source>Image info</source>
         <translation>Informacija o slici</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Open Image</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>All images</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 </TS>
\ No newline at end of file
