@@ -9,14 +9,6 @@
         <source>Version:</source>
         <translation>Versione:</translation>
     </message>
-    <message>
-        <source>Deepin Image Viewer is a fashion &amp; smooth image manager.</source>
-        <translation>Deepin Image Viewer è un gestore immagini bello e veloce.</translation>
-    </message>
-    <message>
-        <source>It is featured with image management, image viewing and basic image editing.</source>
-        <translation>Fornisce una gestione delle immagini, la loro visualizzazione ed un editing base.</translation>
-    </message>
 </context>
 <context>
     <name>AlbumBTContent</name>
@@ -255,10 +247,6 @@
         <source>Copy to clipboard</source>
         <translation>Copia negli appunti</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Elimina</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Rimuovi dall&apos;album</translation>
@@ -307,6 +295,10 @@
         <source>Add to new album</source>
         <translation>Aggiungi in un nuovo album</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Elimina</translation>
+    </message>
 </context>
 <context>
     <name>Importer</name>
@@ -341,8 +333,8 @@
         <translation>Data modifica</translation>
     </message>
     <message>
-        <source>Resolution</source>
-        <translation>Risoluzione</translation>
+        <source>Dimension</source>
+        <translation>Dimensione</translation>
     </message>
     <message>
         <source>File size</source>
@@ -448,6 +440,13 @@
         <translation>Impostazioni immagine</translation>
     </message>
 </context>
+<context>
+    <name>PrintPreviewDialog</name>
+    <message>
+        <source>Image Settings</source>
+        <translation>Impostazioni immagine</translation>
+    </message>
+</context>
 <context>
     <name>QObject</name>
     <message>
@@ -547,10 +546,6 @@
         <source>Copy</source>
         <translation>Copia</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Elimina</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Rimuovi dall&apos;album</translation>
@@ -619,6 +614,10 @@
         <source>Display shortcuts</source>
         <translation>Visualizza scorciatoie</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Elimina</translation>
+    </message>
 </context>
 <context>
     <name>ShortcutEditor</name>
@@ -672,10 +671,6 @@
         <source>Copy</source>
         <translation>Copia</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Elimina</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Rimuovi dall&apos;album</translation>
@@ -785,10 +780,6 @@
         <source>Rotate clockwise</source>
         <translation>Ruota in senso orario</translation>
     </message>
-    <message>
-        <source>Throw to Trash</source>
-        <translation>Sposta nel cestino</translation>
-    </message>
     <message>
         <source>Unfavorite</source>
         <translation>Rimuovi dai preferiti</translation>
@@ -797,6 +788,10 @@
         <source>Favorite</source>
         <translation>Aggiungi ai preferiti</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Elimina</translation>
+    </message>
 </context>
 <context>
     <name>ThumbnailWidget</name>
@@ -804,6 +799,10 @@
         <source>No image files found</source>
         <translation>File immagine non trovato</translation>
     </message>
+    <message>
+        <source>Open Image</source>
+        <translation>Apri immagine</translation>
+    </message>
 </context>
 <context>
     <name>TimelineBTContent</name>
@@ -870,10 +869,6 @@
         <source>Copy to clipboard</source>
         <translation>Copia negli appunti</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Elimina</translation>
-    </message>
     <message>
         <source>Favorite</source>
         <translation>Preferita</translation>
@@ -902,6 +897,10 @@
         <source>Image info</source>
         <translation>Info immagine</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Elimina</translation>
+    </message>
 </context>
 <context>
     <name>TitleFrame</name>
@@ -967,6 +966,11 @@
         <source>Dark theme</source>
         <translation>Tema scuro</translation>
     </message>
+    <message>
+        <source>Deepin Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
+        <translation>Deepin Image Viewer è un gestore di immagini elegante e veloce.
+Localizzazione italiana a cura di Massimo A. Carofano.</translation>
+    </message>
 </context>
 <context>
     <name>ViewPanel</name>
@@ -1006,10 +1010,6 @@
         <source>Copy to clipboard</source>
         <translation>Copia negli appunti</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Elimina</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Rimuovi dall&apos;album</translation>
@@ -1050,5 +1050,17 @@
         <source>Image info</source>
         <translation>Info immagine</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Elimina</translation>
+    </message>
+    <message>
+        <source>Open Image</source>
+        <translation>Apri immagine</translation>
+    </message>
+    <message>
+        <source>All images</source>
+        <translation>Tutte le immagini</translation>
+    </message>
 </context>
 </TS>
\ No newline at end of file
