@@ -9,14 +9,6 @@
         <source>Version:</source>
         <translation>Versija:</translation>
     </message>
-    <message>
-        <source>Deepin Image Viewer is a fashion &amp; smooth image manager.</source>
-        <translation>Deepin paveikslų žiūryklė yra šiuolaikinė ir glotni paveikslų tvarkytuvė.</translation>
-    </message>
-    <message>
-        <source>It is featured with image management, image viewing and basic image editing.</source>
-        <translation>Jos pagrindinės ypatybės yra paveikslų tvarkymas, paveikslų rodymas bei pagrindinės paveikslų redagavimo funkcijos.</translation>
-    </message>
 </context>
 <context>
     <name>AlbumBTContent</name>
@@ -255,10 +247,6 @@
         <source>Copy to clipboard</source>
         <translation>Kopijuoti į iškarpinę</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Perkelti į šiukšlinę</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Šalinti iš albumo</translation>
@@ -307,6 +295,10 @@
         <source>Add to new album</source>
         <translation>Pridėti į naują albumą</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Ištrinti</translation>
+    </message>
 </context>
 <context>
     <name>Importer</name>
@@ -341,8 +333,8 @@
         <translation>Keitimo data</translation>
     </message>
     <message>
-        <source>Resolution</source>
-        <translation>Raiška</translation>
+        <source>Dimension</source>
+        <translation>Matmenys</translation>
     </message>
     <message>
         <source>File size</source>
@@ -409,45 +401,52 @@
     <name>PrintOptionsPage</name>
     <message>
         <source>No scaling</source>
-        <translation type="unfinished"/>
+        <translation>Nekeisti mastelio</translation>
     </message>
     <message>
         <source>Fit page to image</source>
-        <translation type="unfinished"/>
+        <translation>Talpinti puslapį į paveikslą</translation>
     </message>
     <message>
         <source>Fit image to page</source>
-        <translation type="unfinished"/>
+        <translation>Talpinti paveikslą į puslapį</translation>
     </message>
     <message>
         <source>Scale to:</source>
-        <translation type="unfinished"/>
+        <translation>Keisti mastelį į:</translation>
     </message>
     <message>
         <source>Millimeters</source>
-        <translation type="unfinished"/>
+        <translation>Milimetrų</translation>
     </message>
     <message>
         <source>Centimeters</source>
-        <translation type="unfinished"/>
+        <translation>Centimetrų</translation>
     </message>
     <message>
         <source>Inches</source>
-        <translation type="unfinished"/>
+        <translation>Colių</translation>
     </message>
     <message>
         <source>Image Position</source>
-        <translation type="unfinished"/>
+        <translation>Paveikslo pozicija</translation>
     </message>
     <message>
         <source>Scaling</source>
-        <translation type="unfinished"/>
+        <translation>Mastelio keitimas</translation>
     </message>
     <message>
         <source>Image Settings</source>
         <translation>Paveikslo nustatymai</translation>
     </message>
 </context>
+<context>
+    <name>PrintPreviewDialog</name>
+    <message>
+        <source>Image Settings</source>
+        <translation>Paveikslo nustatymai</translation>
+    </message>
+</context>
 <context>
     <name>QObject</name>
     <message>
@@ -547,10 +546,6 @@
         <source>Copy</source>
         <translation>Kopijuoti</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Perkelti į šiukšlinę</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Šalinti iš albumo</translation>
@@ -619,6 +614,10 @@
         <source>Display shortcuts</source>
         <translation>Rodyti trumpinius</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Ištrinti</translation>
+    </message>
 </context>
 <context>
     <name>ShortcutEditor</name>
@@ -672,10 +671,6 @@
         <source>Copy</source>
         <translation>Kopijuoti</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Perkelti į šiukšlinę</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Šalinti iš albumo</translation>
@@ -785,10 +780,6 @@
         <source>Rotate clockwise</source>
         <translation>Pasukti pagal laikrodžio rodyklę</translation>
     </message>
-    <message>
-        <source>Throw to Trash</source>
-        <translation>Perkelti į šiukšlinę</translation>
-    </message>
     <message>
         <source>Unfavorite</source>
         <translation>Nebemėgstamas</translation>
@@ -797,6 +788,10 @@
         <source>Favorite</source>
         <translation>Mėgstamas</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Ištrinti</translation>
+    </message>
 </context>
 <context>
     <name>ThumbnailWidget</name>
@@ -804,6 +799,10 @@
         <source>No image files found</source>
         <translation>Nerasta jokių paveikslo failų</translation>
     </message>
+    <message>
+        <source>Open Image</source>
+        <translation>Atverti paveikslą</translation>
+    </message>
 </context>
 <context>
     <name>TimelineBTContent</name>
@@ -870,10 +869,6 @@
         <source>Copy to clipboard</source>
         <translation>Kopijuoti į iškarpinę</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Perkelti į šiukšlinę</translation>
-    </message>
     <message>
         <source>Favorite</source>
         <translation>Mėgstamas</translation>
@@ -902,6 +897,10 @@
         <source>Image info</source>
         <translation>Paveikslo informacija</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Ištrinti</translation>
+    </message>
 </context>
 <context>
     <name>TitleFrame</name>
@@ -967,6 +966,10 @@
         <source>Dark theme</source>
         <translation>Tamsi tema</translation>
     </message>
+    <message>
+        <source>Deepin Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
+        <translation>Deepin paveikslų žiūryklė yra paveikslų peržiūros įrankis su šiuolaikine sąsaja ir glotniu našumu.</translation>
+    </message>
 </context>
 <context>
     <name>ViewPanel</name>
@@ -1006,10 +1009,6 @@
         <source>Copy to clipboard</source>
         <translation>Kopijuoti į iškarpinę</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Perkelti į šiukšlinę</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Šalinti iš albumo</translation>
@@ -1050,5 +1049,17 @@
         <source>Image info</source>
         <translation>Paveikslo informacija</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Ištrinti</translation>
+    </message>
+    <message>
+        <source>Open Image</source>
+        <translation>Atverti paveikslą</translation>
+    </message>
+    <message>
+        <source>All images</source>
+        <translation>Visi paveikslai</translation>
+    </message>
 </context>
 </TS>
\ No newline at end of file
