@@ -9,14 +9,6 @@
         <source>Version:</source>
         <translation>Versi:</translation>
     </message>
-    <message>
-        <source>Deepin Image Viewer is a fashion &amp; smooth image manager.</source>
-        <translation>Pelihat Imej Deepin merupakan pengurus imej yang berfesyen &amp; lancar.</translation>
-    </message>
-    <message>
-        <source>It is featured with image management, image viewing and basic image editing.</source>
-        <translation>Ia difiturkan dengan pengurusan imej, pemaparan imej dan penyuntingan imej asas.</translation>
-    </message>
 </context>
 <context>
     <name>AlbumBTContent</name>
@@ -255,10 +247,6 @@
         <source>Copy to clipboard</source>
         <translation>Salin ke papan keratan</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Campak ke dalam tong sampah</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Buang dari album</translation>
@@ -307,6 +295,10 @@
         <source>Add to new album</source>
         <translation>Tambah ke album baharu</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Padam</translation>
+    </message>
 </context>
 <context>
     <name>Importer</name>
@@ -341,8 +333,8 @@
         <translation>Tarikh diubahsuai</translation>
     </message>
     <message>
-        <source>Resolution</source>
-        <translation>Resolusi</translation>
+        <source>Dimension</source>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>File size</source>
@@ -448,6 +440,13 @@
         <translation>Tetapan Imej</translation>
     </message>
 </context>
+<context>
+    <name>PrintPreviewDialog</name>
+    <message>
+        <source>Image Settings</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>QObject</name>
     <message>
@@ -547,10 +546,6 @@
         <source>Copy</source>
         <translation>Salin</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Campak ke dalam tong sampah</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Buang dari album</translation>
@@ -619,6 +614,10 @@
         <source>Display shortcuts</source>
         <translation>Papar pintasan</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Padam</translation>
+    </message>
 </context>
 <context>
     <name>ShortcutEditor</name>
@@ -672,10 +671,6 @@
         <source>Copy</source>
         <translation>Salin</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Campak ke dalam tong sampah</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Buang dari album</translation>
@@ -785,10 +780,6 @@
         <source>Rotate clockwise</source>
         <translation>Putar ikut jam</translation>
     </message>
-    <message>
-        <source>Throw to Trash</source>
-        <translation>Campak ke dalam Tong Sampah</translation>
-    </message>
     <message>
         <source>Unfavorite</source>
         <translation>Nyahgemar</translation>
@@ -797,6 +788,10 @@
         <source>Favorite</source>
         <translation>Kegemaran</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Padam</translation>
+    </message>
 </context>
 <context>
     <name>ThumbnailWidget</name>
@@ -804,6 +799,10 @@
         <source>No image files found</source>
         <translation>Tiada fail imej ditemui</translation>
     </message>
+    <message>
+        <source>Open Image</source>
+        <translation>Buka Imej</translation>
+    </message>
 </context>
 <context>
     <name>TimelineBTContent</name>
@@ -870,10 +869,6 @@
         <source>Copy to clipboard</source>
         <translation>Salin ke papan keratan</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Campak ke dalam tong sampah</translation>
-    </message>
     <message>
         <source>Favorite</source>
         <translation>Kegemaran</translation>
@@ -902,6 +897,10 @@
         <source>Image info</source>
         <translation>Maklumat imej</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Padam</translation>
+    </message>
 </context>
 <context>
     <name>TitleFrame</name>
@@ -967,6 +966,10 @@
         <source>Dark theme</source>
         <translation>Tema gelap</translation>
     </message>
+    <message>
+        <source>Deepin Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
+        <translation>Pelihat Imej Deepin merupakan pengurus imej dengan antaramuka berfesyen dan prestasi yang lancar.</translation>
+    </message>
 </context>
 <context>
     <name>ViewPanel</name>
@@ -1006,10 +1009,6 @@
         <source>Copy to clipboard</source>
         <translation>Salin ke papan keratan</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Campak ke dalam tong sampah</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Buang dari album</translation>
@@ -1050,5 +1049,17 @@
         <source>Image info</source>
         <translation>Maklumat imej</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Padam</translation>
+    </message>
+    <message>
+        <source>Open Image</source>
+        <translation>Buka Imej</translation>
+    </message>
+    <message>
+        <source>All images</source>
+        <translation>Semua imej</translation>
+    </message>
 </context>
 </TS>
\ No newline at end of file
