@@ -9,14 +9,6 @@
         <source>Version:</source>
         <translation>Wersja:</translation>
     </message>
-    <message>
-        <source>Deepin Image Viewer is a fashion &amp; smooth image manager.</source>
-        <translation>Przeglądarka zdjęć Deepin jest modnym i płynnie działającym menedżerem obrazów.</translation>
-    </message>
-    <message>
-        <source>It is featured with image management, image viewing and basic image editing.</source>
-        <translation>Wyposażony jest w funkcje zarządzania obrazami, podglądu obrazów i podstawowej ich modyfikacji.</translation>
-    </message>
 </context>
 <context>
     <name>AlbumBTContent</name>
@@ -255,10 +247,6 @@
         <source>Copy to clipboard</source>
         <translation>Kopiuj do schowka</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Wyrzuć do kosza</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Usuń z albumu</translation>
@@ -307,6 +295,10 @@
         <source>Add to new album</source>
         <translation>Dodaj do nowego albumu</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Usuń</translation>
+    </message>
 </context>
 <context>
     <name>Importer</name>
@@ -341,8 +333,8 @@
         <translation>Data modyfikacji</translation>
     </message>
     <message>
-        <source>Resolution</source>
-        <translation>Rozdzielczość</translation>
+        <source>Dimension</source>
+        <translation>Wymiar</translation>
     </message>
     <message>
         <source>File size</source>
@@ -448,6 +440,13 @@
         <translation>Ustawienia obrazu</translation>
     </message>
 </context>
+<context>
+    <name>PrintPreviewDialog</name>
+    <message>
+        <source>Image Settings</source>
+        <translation>Ustawienia obrazu</translation>
+    </message>
+</context>
 <context>
     <name>QObject</name>
     <message>
@@ -547,10 +546,6 @@
         <source>Copy</source>
         <translation>Kopiuj</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Wyrzuć do kosza</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Usuń z albumu</translation>
@@ -619,6 +614,10 @@
         <source>Display shortcuts</source>
         <translation>Wyświetl skróty</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Usuń</translation>
+    </message>
 </context>
 <context>
     <name>ShortcutEditor</name>
@@ -672,10 +671,6 @@
         <source>Copy</source>
         <translation>Kopiuj</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Wyrzuć do kosza</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Usuń z albumu</translation>
@@ -785,10 +780,6 @@
         <source>Rotate clockwise</source>
         <translation>Obróć zgodnie z kierunkiem wskazówek zegara</translation>
     </message>
-    <message>
-        <source>Throw to Trash</source>
-        <translation>Wyrzuć do kosza</translation>
-    </message>
     <message>
         <source>Unfavorite</source>
         <translation>Usuń z ulubionych</translation>
@@ -797,6 +788,10 @@
         <source>Favorite</source>
         <translation>Ulubione</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Usuń</translation>
+    </message>
 </context>
 <context>
     <name>ThumbnailWidget</name>
@@ -804,6 +799,10 @@
         <source>No image files found</source>
         <translation>Nie odnaleziono plików z obrazami</translation>
     </message>
+    <message>
+        <source>Open Image</source>
+        <translation>Otwórz obraz</translation>
+    </message>
 </context>
 <context>
     <name>TimelineBTContent</name>
@@ -870,10 +869,6 @@
         <source>Copy to clipboard</source>
         <translation>Kopiuj do schowka</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Wyrzuć do kosza</translation>
-    </message>
     <message>
         <source>Favorite</source>
         <translation>Ulubione</translation>
@@ -902,6 +897,10 @@
         <source>Image info</source>
         <translation>Informacje o obrazie</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Usuń</translation>
+    </message>
 </context>
 <context>
     <name>TitleFrame</name>
@@ -967,6 +966,10 @@
         <source>Dark theme</source>
         <translation>Ciemny motyw</translation>
     </message>
+    <message>
+        <source>Deepin Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
+        <translation>Przeglądarka zdjęć Deepin to narzędzie przeglądania obrazów z modnym interfejsem i płynnym działaniem.</translation>
+    </message>
 </context>
 <context>
     <name>ViewPanel</name>
@@ -1006,10 +1009,6 @@
         <source>Copy to clipboard</source>
         <translation>Kopiuj do schowka</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Wyrzuć do kosza</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Usuń z albumu</translation>
@@ -1050,5 +1049,17 @@
         <source>Image info</source>
         <translation>Informacje o obrazie</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Usuń</translation>
+    </message>
+    <message>
+        <source>Open Image</source>
+        <translation>Otwórz obraz</translation>
+    </message>
+    <message>
+        <source>All images</source>
+        <translation>Wszystkie obrazy</translation>
+    </message>
 </context>
 </TS>
\ No newline at end of file
