@@ -9,14 +9,6 @@
         <source>Version:</source>
         <translation>Versão:</translation>
     </message>
-    <message>
-        <source>Deepin Image Viewer is a fashion &amp; smooth image manager.</source>
-        <translation>O Deepin Image Viewer é um bonito e fluído gestor de imagens.</translation>
-    </message>
-    <message>
-        <source>It is featured with image management, image viewing and basic image editing.</source>
-        <translation>Isto tem a função de gerir, visualizar e editar rudimentarmente imagens.   </translation>
-    </message>
 </context>
 <context>
     <name>AlbumBTContent</name>
@@ -30,11 +22,11 @@
     </message>
     <message>
         <source>album</source>
-        <translation>album</translation>
+        <translation>álbum</translation>
     </message>
     <message>
         <source>albums</source>
-        <translation>albuns</translation>
+        <translation>álbuns</translation>
     </message>
     <message>
         <source>Manage sync</source>
@@ -57,7 +49,7 @@
     </message>
     <message>
         <source>New album</source>
-        <translation>Novo album</translation>
+        <translation>Novo álbum</translation>
     </message>
     <message>
         <source>Unnamed</source>
@@ -72,14 +64,14 @@
     </message>
     <message>
         <source>My favorite</source>
-        <translation>Meus favoritos</translation>
+        <translation>Os meus favoritos</translation>
     </message>
 </context>
 <context>
     <name>AlbumDeleteDialog</name>
     <message>
         <source>Are your sure to delete this album?</source>
-        <translation>Tem a certeza que deseja eliminar este album?</translation>
+        <translation>Tem a certeza que deseja eliminar este álbum?</translation>
     </message>
     <message>
         <source>Cancel</source>
@@ -94,11 +86,11 @@
     <name>AlbumPanel</name>
     <message>
         <source>Back</source>
-        <translation>Voltar</translation>
+        <translation>Anterior</translation>
     </message>
     <message>
         <source>My favorite</source>
-        <translation>Meus favoritos</translation>
+        <translation>Os meus favoritos</translation>
     </message>
     <message>
         <source>Timeline</source>
@@ -125,7 +117,7 @@
     </message>
     <message>
         <source>Slide show</source>
-        <translation>Apresentação de Slides</translation>
+        <translation>Diaporama</translation>
     </message>
     <message>
         <source>Rename</source>
@@ -166,7 +158,7 @@
     </message>
     <message>
         <source>Are you sure to add the pictures to the album?</source>
-        <translation>Tem a certeza que deseja adicionar estas imagens para o album?</translation>
+        <translation>Tem a certeza que deseja adicionar estas imagens ao álbum?</translation>
     </message>
     <message>
         <source>Sync and Create</source>
@@ -255,10 +247,6 @@
         <source>Copy to clipboard</source>
         <translation>Copiar para área de transferência</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Enviar para o lixo</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Remover do album</translation>
@@ -307,6 +295,10 @@
         <source>Add to new album</source>
         <translation>Adicionar a um novo album</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Eliminar</translation>
+    </message>
 </context>
 <context>
     <name>Importer</name>
@@ -341,8 +333,8 @@
         <translation>Data de modificação</translation>
     </message>
     <message>
-        <source>Resolution</source>
-        <translation>Resolução</translation>
+        <source>Dimension</source>
+        <translation>Dimensão</translation>
     </message>
     <message>
         <source>File size</source>
@@ -448,6 +440,13 @@
         <translation>Definições da Imagem</translation>
     </message>
 </context>
+<context>
+    <name>PrintPreviewDialog</name>
+    <message>
+        <source>Image Settings</source>
+        <translation>Definições de imagem</translation>
+    </message>
+</context>
 <context>
     <name>QObject</name>
     <message>
@@ -547,10 +546,6 @@
         <source>Copy</source>
         <translation>Copiar</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Enviar para o lixo</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Remover do album</translation>
@@ -619,6 +614,10 @@
         <source>Display shortcuts</source>
         <translation>Mostrar atalhos</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Eliminar</translation>
+    </message>
 </context>
 <context>
     <name>ShortcutEditor</name>
@@ -672,10 +671,6 @@
         <source>Copy</source>
         <translation>Copiar</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Enviar para o lixo</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Remover do album</translation>
@@ -785,10 +780,6 @@
         <source>Rotate clockwise</source>
         <translation>Rodas a favor dos ponteiros do relógio</translation>
     </message>
-    <message>
-        <source>Throw to Trash</source>
-        <translation>Atirar para o lixo</translation>
-    </message>
     <message>
         <source>Unfavorite</source>
         <translation>Remover favorito</translation>
@@ -797,6 +788,10 @@
         <source>Favorite</source>
         <translation>Favorito</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Eliminar</translation>
+    </message>
 </context>
 <context>
     <name>ThumbnailWidget</name>
@@ -804,6 +799,10 @@
         <source>No image files found</source>
         <translation>Sem ficheiros de imagem encontrados</translation>
     </message>
+    <message>
+        <source>Open Image</source>
+        <translation>Abrir Imagem</translation>
+    </message>
 </context>
 <context>
     <name>TimelineBTContent</name>
@@ -870,10 +869,6 @@
         <source>Copy to clipboard</source>
         <translation>Copiar para área de transferência</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Enviar para o lixo</translation>
-    </message>
     <message>
         <source>Favorite</source>
         <translation>Favorito</translation>
@@ -902,6 +897,10 @@
         <source>Image info</source>
         <translation>Informação da imagem</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Eliminar</translation>
+    </message>
 </context>
 <context>
     <name>TitleFrame</name>
@@ -967,6 +966,10 @@
         <source>Dark theme</source>
         <translation>Tema Escuro</translation>
     </message>
+    <message>
+        <source>Deepin Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
+        <translation>O Deepin Image Viewer é uma ferramenta com um bonito aspeto e um desempenho fluído para visualizar imagens.</translation>
+    </message>
 </context>
 <context>
     <name>ViewPanel</name>
@@ -1006,10 +1009,6 @@
         <source>Copy to clipboard</source>
         <translation>Copiar para área de transferência</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Enviar para o lixo</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Remover do album</translation>
@@ -1050,5 +1049,17 @@
         <source>Image info</source>
         <translation>Informação da imagem</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Eliminar</translation>
+    </message>
+    <message>
+        <source>Open Image</source>
+        <translation>Abrir Imagem</translation>
+    </message>
+    <message>
+        <source>All images</source>
+        <translation>Todas as imagens</translation>
+    </message>
 </context>
 </TS>
\ No newline at end of file
