@@ -3,20 +3,12 @@
     <name>AboutDialog</name>
     <message>
         <source>Deepin Image Viewer</source>
-        <translation>Deepin Image Viewer</translation>
+        <translation>Visualizador de Imagens</translation>
     </message>
     <message>
         <source>Version:</source>
         <translation>Versão:</translation>
     </message>
-    <message>
-        <source>Deepin Image Viewer is a fashion &amp; smooth image manager.</source>
-        <translation>Deepin Image Viewer é um gerenciador de imagens moderno e sutil.</translation>
-    </message>
-    <message>
-        <source>It is featured with image management, image viewing and basic image editing.</source>
-        <translation>Seus recursos incluem gerenciamento, visualização e edição básica de imagens.</translation>
-    </message>
 </context>
 <context>
     <name>AlbumBTContent</name>
@@ -255,10 +247,6 @@
         <source>Copy to clipboard</source>
         <translation>Copiar para área de transferência</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Enviar para a lixeira</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Remover do álbum</translation>
@@ -307,6 +295,10 @@
         <source>Add to new album</source>
         <translation>Adicionar ao novo álbum</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Excluir</translation>
+    </message>
 </context>
 <context>
     <name>Importer</name>
@@ -341,8 +333,8 @@
         <translation>Data modificada</translation>
     </message>
     <message>
-        <source>Resolution</source>
-        <translation>Resolução</translation>
+        <source>Dimension</source>
+        <translation>Dimensão</translation>
     </message>
     <message>
         <source>File size</source>
@@ -409,7 +401,7 @@
     <name>PrintOptionsPage</name>
     <message>
         <source>No scaling</source>
-        <translation type="unfinished"/>
+        <translation>Sem escala</translation>
     </message>
     <message>
         <source>Fit page to image</source>
@@ -421,7 +413,7 @@
     </message>
     <message>
         <source>Scale to:</source>
-        <translation type="unfinished"/>
+        <translation>Escalar para:</translation>
     </message>
     <message>
         <source>Millimeters</source>
@@ -441,13 +433,20 @@
     </message>
     <message>
         <source>Scaling</source>
-        <translation type="unfinished"/>
+        <translation>Escala</translation>
     </message>
     <message>
         <source>Image Settings</source>
         <translation>Configurações da Imagem</translation>
     </message>
 </context>
+<context>
+    <name>PrintPreviewDialog</name>
+    <message>
+        <source>Image Settings</source>
+        <translation>Configurações da Imagem</translation>
+    </message>
+</context>
 <context>
     <name>QObject</name>
     <message>
@@ -547,10 +546,6 @@
         <source>Copy</source>
         <translation>Copiar</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Enviar para a lixeira</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Remover do álbum</translation>
@@ -619,6 +614,10 @@
         <source>Display shortcuts</source>
         <translation>Exibir atalhos</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Excluir</translation>
+    </message>
 </context>
 <context>
     <name>ShortcutEditor</name>
@@ -672,10 +671,6 @@
         <source>Copy</source>
         <translation>Copiar</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Enviar para a lixeira</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Remover do álbum</translation>
@@ -785,10 +780,6 @@
         <source>Rotate clockwise</source>
         <translation>Girar no sentido horário</translation>
     </message>
-    <message>
-        <source>Throw to Trash</source>
-        <translation>Jogar na Lixeira</translation>
-    </message>
     <message>
         <source>Unfavorite</source>
         <translation>Desfavoritar</translation>
@@ -797,6 +788,10 @@
         <source>Favorite</source>
         <translation>Favoritar</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Excluir</translation>
+    </message>
 </context>
 <context>
     <name>ThumbnailWidget</name>
@@ -804,6 +799,10 @@
         <source>No image files found</source>
         <translation>Nenhum arquivo de imagem encontrado</translation>
     </message>
+    <message>
+        <source>Open Image</source>
+        <translation>Abrir Imagem</translation>
+    </message>
 </context>
 <context>
     <name>TimelineBTContent</name>
@@ -870,10 +869,6 @@
         <source>Copy to clipboard</source>
         <translation>Copiar para área de transferência</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Enviar para a lixeira</translation>
-    </message>
     <message>
         <source>Favorite</source>
         <translation>Favorito</translation>
@@ -902,6 +897,10 @@
         <source>Image info</source>
         <translation>Informações</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Excluir</translation>
+    </message>
 </context>
 <context>
     <name>TitleFrame</name>
@@ -957,7 +956,7 @@
     </message>
     <message>
         <source>Deepin Image Viewer is a fashion &amp; smooth image manager.</source>
-        <translation>Deepin Image Viewer é um gerenciador de imagens moderno e sutil.</translation>
+        <translation>Visualizador de Imagens é um gerenciador de imagens moderno e sutil.</translation>
     </message>
     <message>
         <source>It is featured with image management, image viewing and basic image editing.</source>
@@ -965,7 +964,11 @@
     </message>
     <message>
         <source>Dark theme</source>
-        <translation>Tema dark</translation>
+        <translation>Tema Escuro</translation>
+    </message>
+    <message>
+        <source>Deepin Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
+        <translation>O Deepin Image Viewer é uma ferramenta de visualização de imagens com interface fashion e ótimo desempenho.</translation>
     </message>
 </context>
 <context>
@@ -1006,10 +1009,6 @@
         <source>Copy to clipboard</source>
         <translation>Copiar para área de transferência</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Enviar para a lixeira</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Remover do álbum</translation>
@@ -1050,5 +1049,17 @@
         <source>Image info</source>
         <translation>Informações</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Excluir</translation>
+    </message>
+    <message>
+        <source>Open Image</source>
+        <translation>Abrir Imagem</translation>
+    </message>
+    <message>
+        <source>All images</source>
+        <translation>Todas as imagens</translation>
+    </message>
 </context>
 </TS>
\ No newline at end of file
