@@ -9,14 +9,6 @@
         <source>Version:</source>
         <translation>Версия:</translation>
     </message>
-    <message>
-        <source>Deepin Image Viewer is a fashion &amp; smooth image manager.</source>
-        <translation>Просмотр изображений Deepin является современным и гладким менеджером изображений.</translation>
-    </message>
-    <message>
-        <source>It is featured with image management, image viewing and basic image editing.</source>
-        <translation>Он имеет функции управления просмотра и редактирования основных изображений.</translation>
-    </message>
 </context>
 <context>
     <name>AlbumBTContent</name>
@@ -255,10 +247,6 @@
         <source>Copy to clipboard</source>
         <translation>Копировать в буфер обмена</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Выбросить в корзину</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Удалить из альбома</translation>
@@ -307,6 +295,10 @@
         <source>Add to new album</source>
         <translation>Добавить новый альбом</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Удалить</translation>
+    </message>
 </context>
 <context>
     <name>Importer</name>
@@ -341,8 +333,8 @@
         <translation>Дата изменения</translation>
     </message>
     <message>
-        <source>Resolution</source>
-        <translation>Разрешение</translation>
+        <source>Dimension</source>
+        <translation>Измерение</translation>
     </message>
     <message>
         <source>File size</source>
@@ -448,6 +440,13 @@
         <translation>Настройки Изображения</translation>
     </message>
 </context>
+<context>
+    <name>PrintPreviewDialog</name>
+    <message>
+        <source>Image Settings</source>
+        <translation>Настройки Изображения</translation>
+    </message>
+</context>
 <context>
     <name>QObject</name>
     <message>
@@ -547,10 +546,6 @@
         <source>Copy</source>
         <translation>Копировать</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Выбросить в корзину</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Удалить из альбома</translation>
@@ -619,6 +614,10 @@
         <source>Display shortcuts</source>
         <translation>Показать сочетания</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Удалить</translation>
+    </message>
 </context>
 <context>
     <name>ShortcutEditor</name>
@@ -672,10 +671,6 @@
         <source>Copy</source>
         <translation>Копировать</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Выбросить в корзину</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Удалить из альбома</translation>
@@ -785,10 +780,6 @@
         <source>Rotate clockwise</source>
         <translation>Вращать по часовой стрелке</translation>
     </message>
-    <message>
-        <source>Throw to Trash</source>
-        <translation>Выбросить в Корзину</translation>
-    </message>
     <message>
         <source>Unfavorite</source>
         <translation>Удалить из избранного</translation>
@@ -797,6 +788,10 @@
         <source>Favorite</source>
         <translation>Избранное</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Удалить</translation>
+    </message>
 </context>
 <context>
     <name>ThumbnailWidget</name>
@@ -804,6 +799,10 @@
         <source>No image files found</source>
         <translation>Изображение не найдено</translation>
     </message>
+    <message>
+        <source>Open Image</source>
+        <translation>Открыть Файл Изображения</translation>
+    </message>
 </context>
 <context>
     <name>TimelineBTContent</name>
@@ -870,10 +869,6 @@
         <source>Copy to clipboard</source>
         <translation>Копировать в буфер обмена</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Выбросить в корзину</translation>
-    </message>
     <message>
         <source>Favorite</source>
         <translation>Избранное</translation>
@@ -902,6 +897,10 @@
         <source>Image info</source>
         <translation>Информация о изображении</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Удалить</translation>
+    </message>
 </context>
 <context>
     <name>TitleFrame</name>
@@ -967,6 +966,10 @@
         <source>Dark theme</source>
         <translation>Темная тема</translation>
     </message>
+    <message>
+        <source>Deepin Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
+        <translation>Deepin Image Viewer - это современный плавно работающий и изящный менеджер изображений</translation>
+    </message>
 </context>
 <context>
     <name>ViewPanel</name>
@@ -1006,10 +1009,6 @@
         <source>Copy to clipboard</source>
         <translation>Копировать в буфер обмена</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Выбросить в корзину</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Удалить из альбома</translation>
@@ -1050,5 +1049,17 @@
         <source>Image info</source>
         <translation>Информация о изображении</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Удалить</translation>
+    </message>
+    <message>
+        <source>Open Image</source>
+        <translation>Открыть Файл Изображения</translation>
+    </message>
+    <message>
+        <source>All images</source>
+        <translation>Все изображения</translation>
+    </message>
 </context>
 </TS>
\ No newline at end of file
