@@ -9,14 +9,6 @@
         <source>Version:</source>
         <translation>Верзија:</translation>
     </message>
-    <message>
-        <source>Deepin Image Viewer is a fashion &amp; smooth image manager.</source>
-        <translation>Дипин Прегледач Слика је модеран &amp; префињен управник слика.</translation>
-    </message>
-    <message>
-        <source>It is featured with image management, image viewing and basic image editing.</source>
-        <translation>Својства су му управљање, прегледање и основно уређивање слика.</translation>
-    </message>
 </context>
 <context>
     <name>AlbumBTContent</name>
@@ -26,7 +18,7 @@
     </message>
     <message>
         <source>images</source>
-        <translation>слике</translation>
+        <translation>слика</translation>
     </message>
     <message>
         <source>album</source>
@@ -34,7 +26,7 @@
     </message>
     <message>
         <source>albums</source>
-        <translation>албуми</translation>
+        <translation>албума</translation>
     </message>
     <message>
         <source>Manage sync</source>
@@ -79,7 +71,7 @@
     <name>AlbumDeleteDialog</name>
     <message>
         <source>Are your sure to delete this album?</source>
-        <translation>Сигурно желите да избришете албум?</translation>
+        <translation>Заиста желите да обришете албум?</translation>
     </message>
     <message>
         <source>Cancel</source>
@@ -87,7 +79,7 @@
     </message>
     <message>
         <source>Delete</source>
-        <translation>Избриши</translation>
+        <translation>Обриши</translation>
     </message>
 </context>
 <context>
@@ -110,7 +102,7 @@
     </message>
     <message>
         <source>You can add sync directory or drag and drop  images to timeline</source>
-        <translation>Можете додати директоријум за синхронизациу или превући слике на временску линију</translation>
+        <translation>Можете додати директоријум за синхронизацију или превући слике на временску линију</translation>
     </message>
 </context>
 <context>
@@ -137,7 +129,7 @@
     </message>
     <message>
         <source>Delete</source>
-        <translation>Избриши</translation>
+        <translation>Обриши</translation>
     </message>
 </context>
 <context>
@@ -151,7 +143,7 @@
     <name>CountingThread</name>
     <message>
         <source>Images</source>
-        <translation>слике</translation>
+        <translation>Слика</translation>
     </message>
 </context>
 <context>
@@ -166,19 +158,19 @@
     </message>
     <message>
         <source>Are you sure to add the pictures to the album?</source>
-        <translation>Сигурно желите да додате слике у албум?</translation>
+        <translation>Заиста желите да додате слике у албум?</translation>
     </message>
     <message>
         <source>Sync and Create</source>
-        <translation>Синхро и Направи</translation>
+        <translation>Синхро. и направи</translation>
     </message>
     <message>
         <source>Sync</source>
-        <translation>Синхро</translation>
+        <translation>Синхро.</translation>
     </message>
     <message>
         <source>Are you sure to add to the sync list and create the album named after this folder?</source>
-        <translation>Желите ли да додате на листу синхронизације и направите албум именован по датотеци?</translation>
+        <translation>Желите ли да додате на листу синхронизације и направите албум именован по овој фасцикли?</translation>
     </message>
 </context>
 <context>
@@ -212,7 +204,7 @@
     </message>
     <message>
         <source>Delete</source>
-        <translation>Избриши</translation>
+        <translation>Обриши</translation>
     </message>
 </context>
 <context>
@@ -255,10 +247,6 @@
         <source>Copy to clipboard</source>
         <translation>Копирај у бележницу</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Баци у смеће</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Уклони из албума</translation>
@@ -297,7 +285,7 @@
     </message>
     <message>
         <source>You can add sync directory or drag and drop  images to timeline</source>
-        <translation>Можете додати директоријум за синхронизациу или превући слике на временску линију</translation>
+        <translation>Можете додати директоријум за синхронизацију или превући слике на временску линију</translation>
     </message>
     <message>
         <source>Add to album</source>
@@ -307,12 +295,16 @@
         <source>Add to new album</source>
         <translation>Додај у нови албум</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Обриши</translation>
+    </message>
 </context>
 <context>
     <name>Importer</name>
     <message>
         <source>Open Directory</source>
-        <translation>Отвори Директоријум</translation>
+        <translation>Отвори директоријум</translation>
     </message>
 </context>
 <context>
@@ -341,8 +333,8 @@
         <translation>Измењено</translation>
     </message>
     <message>
-        <source>Resolution</source>
-        <translation>Резолуција</translation>
+        <source>Dimension</source>
+        <translation>Димензије</translation>
     </message>
     <message>
         <source>File size</source>
@@ -437,7 +429,7 @@
     </message>
     <message>
         <source>Image Position</source>
-        <translation>Позиција Слике</translation>
+        <translation>Позиција слике</translation>
     </message>
     <message>
         <source>Scaling</source>
@@ -445,7 +437,14 @@
     </message>
     <message>
         <source>Image Settings</source>
-        <translation>Поставке Слике</translation>
+        <translation>Поставке слике</translation>
+    </message>
+</context>
+<context>
+    <name>PrintPreviewDialog</name>
+    <message>
+        <source>Image Settings</source>
+        <translation>Поставке слике</translation>
     </message>
 </context>
 <context>
@@ -471,7 +470,7 @@
     <name>ScanPathsDialog</name>
     <message>
         <source>Select Directory</source>
-        <translation>Одабери Директоријум</translation>
+        <translation>Одабери директоријум</translation>
     </message>
     <message>
         <source>This directory is disabled to sync</source>
@@ -479,22 +478,22 @@
     </message>
     <message>
         <source>Add folder</source>
-        <translation>Додај датотеку</translation>
+        <translation>Додај фасциклу</translation>
     </message>
     <message>
         <source>Sync Directory Management</source>
-        <translation>Управљање Синхронизацијом Директоријума</translation>
+        <translation>Управљање синхронизацијом директоријума</translation>
     </message>
     <message>
         <source>The directory list is empty</source>
-        <translation>Лста диркторијума је празна</translation>
+        <translation>Листа диркторијума је празна</translation>
     </message>
 </context>
 <context>
     <name>ScanPathsItem</name>
     <message>
         <source>Cancel sync</source>
-        <translation>Откажи синхро</translation>
+        <translation>Откажи синхро.</translation>
     </message>
     <message>
         <source>Images</source>
@@ -517,7 +516,7 @@
     <name>Shortcut</name>
     <message>
         <source>Image Viewing</source>
-        <translation>Преглед Слика</translation>
+        <translation>Преглед слика</translation>
     </message>
     <message>
         <source>Album</source>
@@ -547,10 +546,6 @@
         <source>Copy</source>
         <translation>Копирај</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Баци у смеће</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Уклони из албума</translation>
@@ -619,6 +614,10 @@
         <source>Display shortcuts</source>
         <translation>Прикажи пречице</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Обриши</translation>
+    </message>
 </context>
 <context>
     <name>ShortcutEditor</name>
@@ -635,7 +634,7 @@
     </message>
     <message>
         <source>View Picture</source>
-        <translation>Преглед Слике</translation>
+        <translation>Преглед слике</translation>
     </message>
     <message>
         <source>Album</source>
@@ -643,7 +642,7 @@
     </message>
     <message>
         <source>Restore Defaults</source>
-        <translation>Врати Подрзумевано</translation>
+        <translation>Врати подразумевано</translation>
     </message>
 </context>
 <context>
@@ -672,10 +671,6 @@
         <source>Copy</source>
         <translation>Копирај</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Баци у смеће</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Уклони из албума</translation>
@@ -718,7 +713,7 @@
     </message>
     <message>
         <source>Delete</source>
-        <translation>Избриши</translation>
+        <translation>Обриши</translation>
     </message>
 </context>
 <context>
@@ -736,7 +731,7 @@
     <name>SlideshowFrame</name>
     <message>
         <source>Slide Settings</source>
-        <translation>Поставке Покретног Приказа</translation>
+        <translation>Поставке покретног приказа</translation>
     </message>
     <message>
         <source>Switch effect</source>
@@ -785,10 +780,6 @@
         <source>Rotate clockwise</source>
         <translation>Ротирај удесно</translation>
     </message>
-    <message>
-        <source>Throw to Trash</source>
-        <translation>Баци у Смеће</translation>
-    </message>
     <message>
         <source>Unfavorite</source>
         <translation>Из омиљеног</translation>
@@ -797,6 +788,10 @@
         <source>Favorite</source>
         <translation>У омиљено</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Обриши</translation>
+    </message>
 </context>
 <context>
     <name>ThumbnailWidget</name>
@@ -804,6 +799,10 @@
         <source>No image files found</source>
         <translation>Нису пронађене датотеке са сликама</translation>
     </message>
+    <message>
+        <source>Open Image</source>
+        <translation>Отвори слику</translation>
+    </message>
 </context>
 <context>
     <name>TimelineBTContent</name>
@@ -813,7 +812,7 @@
     </message>
     <message>
         <source>%1 images</source>
-        <translation>%1 слике</translation>
+        <translation>%1 слика/е</translation>
     </message>
     <message>
         <source>Manage sync</source>
@@ -836,7 +835,7 @@
     </message>
     <message>
         <source>You can add sync directory or drag and drop  images to timeline</source>
-        <translation>Можете додати директоријум за синхронизациу или превући слике на временску линију</translation>
+        <translation>Можете додати директоријум за синхронизацију или превући слике на временску линију</translation>
     </message>
     <message>
         <source>Add to album</source>
@@ -870,10 +869,6 @@
         <source>Copy to clipboard</source>
         <translation>Копирај у бележницу</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Баци у смеће</translation>
-    </message>
     <message>
         <source>Favorite</source>
         <translation>У омиљено</translation>
@@ -902,12 +897,16 @@
         <source>Image info</source>
         <translation>Својства слике</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Обриши</translation>
+    </message>
 </context>
 <context>
     <name>TitleFrame</name>
     <message>
         <source>Slide Settings</source>
-        <translation>Покретни Приказ</translation>
+        <translation>Покретни приказ</translation>
     </message>
     <message>
         <source>Effect</source>
@@ -961,12 +960,16 @@
     </message>
     <message>
         <source>It is featured with image management, image viewing and basic image editing.</source>
-        <translation>Својства су му управљање, прегледање и основно уређивање слика.</translation>
+        <translation>Омогућава управљање, прегледање и основно уређивање слика.</translation>
     </message>
     <message>
         <source>Dark theme</source>
         <translation>Тамна тема</translation>
     </message>
+    <message>
+        <source>Deepin Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
+        <translation>Дипин Прегледач Слика је алат за приказ слика са модерним сучељем и добрим перформансама.</translation>
+    </message>
 </context>
 <context>
     <name>ViewPanel</name>
@@ -1006,10 +1009,6 @@
         <source>Copy to clipboard</source>
         <translation>Копирај у бележницу</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Баци у смеће</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Уклони из албума</translation>
@@ -1050,5 +1049,17 @@
         <source>Image info</source>
         <translation>Својства слике</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Обриши</translation>
+    </message>
+    <message>
+        <source>Open Image</source>
+        <translation>Отвори слику</translation>
+    </message>
+    <message>
+        <source>All images</source>
+        <translation>Све слике</translation>
+    </message>
 </context>
 </TS>
\ No newline at end of file
