@@ -9,14 +9,6 @@
         <source>Version:</source>
         <translation>Sürüm:</translation>
     </message>
-    <message>
-        <source>Deepin Image Viewer is a fashion &amp; smooth image manager.</source>
-        <translation>Deepin Görsel Görüntüleyici, modern ve sade görsel yöneticisi.</translation>
-    </message>
-    <message>
-        <source>It is featured with image management, image viewing and basic image editing.</source>
-        <translation>Görsel yönetimi, görsel görüntüleme ve basit görsel düzenleme özelliklerini sunar.</translation>
-    </message>
 </context>
 <context>
     <name>AlbumBTContent</name>
@@ -38,7 +30,7 @@
     </message>
     <message>
         <source>Manage sync</source>
-        <translation>Eşitleme yönetimi</translation>
+        <translation>Eşitleme Yönetimi</translation>
     </message>
     <message>
         <source>Syncing: </source>
@@ -57,7 +49,7 @@
     </message>
     <message>
         <source>New album</source>
-        <translation>Yeni albüm</translation>
+        <translation>Yeni Albüm</translation>
     </message>
     <message>
         <source>Unnamed</source>
@@ -98,11 +90,11 @@
     </message>
     <message>
         <source>My favorite</source>
-        <translation>Sık kullandıklarım</translation>
+        <translation>Sık Kullandıklarım</translation>
     </message>
     <message>
         <source>Timeline</source>
-        <translation>Zaman tüneli</translation>
+        <translation>Zaman Tüneli</translation>
     </message>
     <message>
         <source>Add</source>
@@ -125,11 +117,11 @@
     </message>
     <message>
         <source>Slide show</source>
-        <translation>Saydam sunumu</translation>
+        <translation>Saydam Sunumu</translation>
     </message>
     <message>
         <source>Rename</source>
-        <translation>Yeniden adlandır</translation>
+        <translation>Yeniden Adlandır</translation>
     </message>
     <message>
         <source>Copy</source>
@@ -219,7 +211,7 @@
     <name>ImageInfoWidget</name>
     <message>
         <source>Image info</source>
-        <translation>Görsel bilgileri</translation>
+        <translation>Görsel Bilgileri</translation>
     </message>
 </context>
 <context>
@@ -241,7 +233,7 @@
     </message>
     <message>
         <source>Slide show</source>
-        <translation>Saydam sunumu</translation>
+        <translation>Saydam Sunumu</translation>
     </message>
     <message>
         <source>Print</source>
@@ -255,41 +247,37 @@
         <source>Copy to clipboard</source>
         <translation>Panoya kopyala</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Çöpe at</translation>
-    </message>
     <message>
         <source>Remove from album</source>
-        <translation>Albümden kaldır</translation>
+        <translation>Albümden Kaldır</translation>
     </message>
     <message>
         <source>Favorite</source>
-        <translation>Sık kullanılanlara ekle</translation>
+        <translation>Sık Kullanılanlara Ekle</translation>
     </message>
     <message>
         <source>Unfavorite</source>
-        <translation>Sık kullanılanlardan çıkar</translation>
+        <translation>Sık Kullanılanlardan Çıkar</translation>
     </message>
     <message>
         <source>Rotate clockwise</source>
-        <translation>Saat yönünde döndür</translation>
+        <translation>Saat Yönünde Döndür</translation>
     </message>
     <message>
         <source>Rotate counterclockwise</source>
-        <translation>Saat yönünün tersine döndür</translation>
+        <translation>Saat Yönünün Tersine Döndür</translation>
     </message>
     <message>
         <source>Set as wallpaper</source>
-        <translation>Duvar kağıdı olarak ayarla</translation>
+        <translation>Duvar Kağıdı Olarak Ayarla</translation>
     </message>
     <message>
         <source>Display in file manager</source>
-        <translation>Dosya yöneticisinde görüntüle</translation>
+        <translation>Dosya Yöneticisinde Görüntüle</translation>
     </message>
     <message>
         <source>Image info</source>
-        <translation>Görsel bilgileri</translation>
+        <translation>Görsel Bilgileri</translation>
     </message>
     <message>
         <source>Add</source>
@@ -301,11 +289,15 @@
     </message>
     <message>
         <source>Add to album</source>
-        <translation>Albüme ekle</translation>
+        <translation>Albüme Ekle</translation>
     </message>
     <message>
         <source>Add to new album</source>
-        <translation>Yeni albüme ekle</translation>
+        <translation>Yeni Albüme Ekle</translation>
+    </message>
+    <message>
+        <source>Delete</source>
+        <translation>Sil</translation>
     </message>
 </context>
 <context>
@@ -334,35 +326,35 @@
     </message>
     <message>
         <source>Date photoed</source>
-        <translation>Oluşturulma tarihi</translation>
+        <translation>Oluşturulma Tarihi</translation>
     </message>
     <message>
         <source>Date modified</source>
-        <translation>Değiştirilme tarihi</translation>
+        <translation>Değiştirilme Tarihi</translation>
     </message>
     <message>
-        <source>Resolution</source>
-        <translation>Çözünürlük</translation>
+        <source>Dimension</source>
+        <translation>Boyut</translation>
     </message>
     <message>
         <source>File size</source>
-        <translation>Dosya boyutu</translation>
+        <translation>Dosya Boyutu</translation>
     </message>
     <message>
         <source>Colorspace</source>
-        <translation>Renk aralığı</translation>
+        <translation>Renk Aralığı</translation>
     </message>
     <message>
         <source>Exposure mode</source>
-        <translation>Pozlama kipi</translation>
+        <translation>Pozlama Kipi</translation>
     </message>
     <message>
         <source>Exposure program</source>
-        <translation>Pozlama programı</translation>
+        <translation>Pozlama Programı</translation>
     </message>
     <message>
         <source>Exposure time</source>
-        <translation>Pozlama süresi</translation>
+        <translation>Pozlama Süresi</translation>
     </message>
     <message>
         <source>Flash</source>
@@ -382,46 +374,46 @@
     </message>
     <message>
         <source>Max aperture</source>
-        <translation>En yüksek diyafram</translation>
+        <translation>En Yüksek Diyafram</translation>
     </message>
     <message>
         <source>Metering mode</source>
-        <translation>Ölçüm kipi</translation>
+        <translation>Ölçüm Kipi</translation>
     </message>
     <message>
         <source>White balance</source>
-        <translation>Beyaz dengesi</translation>
+        <translation>Beyaz Dengesi</translation>
     </message>
     <message>
         <source>Flash compensation</source>
-        <translation>Flaş dengeleme</translation>
+        <translation>Flaş Dengeleme</translation>
     </message>
     <message>
         <source>Camera model</source>
-        <translation>Kamera modeli</translation>
+        <translation>Kamera Modeli</translation>
     </message>
     <message>
         <source>Lens model</source>
-        <translation>Lens modeli</translation>
+        <translation>Lens Modeli</translation>
     </message>
 </context>
 <context>
     <name>PrintOptionsPage</name>
     <message>
         <source>No scaling</source>
-        <translation>Ölçeklendirme yok</translation>
+        <translation>Ölçeklendirme Yok</translation>
     </message>
     <message>
         <source>Fit page to image</source>
-        <translation>Sayfayı görsele göre ayarla</translation>
+        <translation>Sayfayı Görsele Göre Ayarla</translation>
     </message>
     <message>
         <source>Fit image to page</source>
-        <translation>Görseli sayfaya göre ayarla</translation>
+        <translation>Görseli Sayfaya Göre Ayarla</translation>
     </message>
     <message>
         <source>Scale to:</source>
-        <translation>Şuna ölçeklendir:</translation>
+        <translation>Şuna Ölçeklendir:</translation>
     </message>
     <message>
         <source>Millimeters</source>
@@ -448,6 +440,13 @@
         <translation>Görsel Ayarları</translation>
     </message>
 </context>
+<context>
+    <name>PrintPreviewDialog</name>
+    <message>
+        <source>Image Settings</source>
+        <translation>Görsel Ayarları</translation>
+    </message>
+</context>
 <context>
     <name>QObject</name>
     <message>
@@ -479,7 +478,7 @@
     </message>
     <message>
         <source>Add folder</source>
-        <translation>Klasör ekle</translation>
+        <translation>Klasör Ekle</translation>
     </message>
     <message>
         <source>Sync Directory Management</source>
@@ -494,7 +493,7 @@
     <name>ScanPathsItem</name>
     <message>
         <source>Cancel sync</source>
-        <translation>Eşitlemeyi iptal et</translation>
+        <translation>Eşitlemeyi İptal Et</translation>
     </message>
     <message>
         <source>Images</source>
@@ -537,51 +536,47 @@
     </message>
     <message>
         <source>Slide show</source>
-        <translation>Saydam sunumu</translation>
+        <translation>Saydam Sunumu</translation>
     </message>
     <message>
         <source>End show</source>
-        <translation>Sunumu bitir</translation>
+        <translation>Sunumu Bitirme</translation>
     </message>
     <message>
         <source>Copy</source>
         <translation>Kopyala</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Çöpe at</translation>
-    </message>
     <message>
         <source>Remove from album</source>
-        <translation>Albümden kaldır</translation>
+        <translation>Albümden Kaldırma</translation>
     </message>
     <message>
         <source>Favorite</source>
-        <translation>Sık kullanılanlara ekle</translation>
+        <translation>Sık Kullanılanlara Ekleme</translation>
     </message>
     <message>
         <source>Unfavorite</source>
-        <translation>Sık kullanılandan çıkar</translation>
+        <translation>Sık Kullanılanlardan Çıkarma</translation>
     </message>
     <message>
         <source>Rotate clockwise</source>
-        <translation>Saat yönünde döndür</translation>
+        <translation>Saat Yönünde Döndürme</translation>
     </message>
     <message>
         <source>Rotate counterclockwise</source>
-        <translation>Saat yönünün tersine döndür</translation>
+        <translation>Saat Yönünün Tersine Döndürme</translation>
     </message>
     <message>
         <source>Set as wallpaper</source>
-        <translation>Duvar kağıdı olarak ayarla</translation>
+        <translation>Duvar Kağıdı Olarak Ayarlama</translation>
     </message>
     <message>
         <source>Display in file manager</source>
-        <translation>Dosya yöneticisinde görüntüle</translation>
+        <translation>Dosya Yöneticisinde Görüntüleme</translation>
     </message>
     <message>
         <source>Image info</source>
-        <translation>Görsel bilgileri</translation>
+        <translation>Görsel Bilgilerini Görüntüleme</translation>
     </message>
     <message>
         <source>Previous</source>
@@ -593,19 +588,19 @@
     </message>
     <message>
         <source>Previous screen</source>
-        <translation>Önceki ekran</translation>
+        <translation>Önceki Ekran</translation>
     </message>
     <message>
         <source>Next screen</source>
-        <translation>Sonraki ekran</translation>
+        <translation>Sonraki Ekran</translation>
     </message>
     <message>
         <source>New album</source>
-        <translation>Yeni albüm</translation>
+        <translation>Yeni Albüm Ekleme</translation>
     </message>
     <message>
         <source>Rename</source>
-        <translation>Yeniden adlandır</translation>
+        <translation>Yeniden Adlandırma</translation>
     </message>
     <message>
         <source>Help</source>
@@ -617,7 +612,11 @@
     </message>
     <message>
         <source>Display shortcuts</source>
-        <translation>Kısayolları görüntüle</translation>
+        <translation>Kısayolları Görüntüle</translation>
+    </message>
+    <message>
+        <source>Delete</source>
+        <translation>Sil</translation>
     </message>
 </context>
 <context>
@@ -658,11 +657,11 @@
     </message>
     <message>
         <source>Slide show</source>
-        <translation>Saydam sunumu</translation>
+        <translation>Saydam Sunumu</translation>
     </message>
     <message>
         <source>End show</source>
-        <translation>Sunumu bitir</translation>
+        <translation>Sunumu Bitir</translation>
     </message>
     <message>
         <source>Print</source>
@@ -672,49 +671,45 @@
         <source>Copy</source>
         <translation>Kopyala</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Çöpe at</translation>
-    </message>
     <message>
         <source>Remove from album</source>
-        <translation>Albümden kaldır</translation>
+        <translation>Albümden Kaldır</translation>
     </message>
     <message>
         <source>Favorite</source>
-        <translation>Sık kullanılanlara ekle</translation>
+        <translation>Sık Kullanılanlara Ekle</translation>
     </message>
     <message>
         <source>Unfavorite</source>
-        <translation>Sık kullanılandan çıkar</translation>
+        <translation>Sık Kullanılandan Çıkar</translation>
     </message>
     <message>
         <source>Rotate clockwise</source>
-        <translation>Saat yönünde döndür</translation>
+        <translation>Saat Yönünde Döndür</translation>
     </message>
     <message>
         <source>Rotate counterclockwise</source>
-        <translation>Saat yönünün tersine döndür</translation>
+        <translation>Saat Yönünün Tersine Döndür</translation>
     </message>
     <message>
         <source>Set as wallpaper</source>
-        <translation>Duvar kağıdı olarak ayarla</translation>
+        <translation>Duvar Kağıdı Olarak Ayarla</translation>
     </message>
     <message>
         <source>Display in file manager</source>
-        <translation>Dosya yöneticisinde görüntüle</translation>
+        <translation>Dosya Yöneticisinde Görüntüle</translation>
     </message>
     <message>
         <source>Image info</source>
-        <translation>Görsel bilgileri</translation>
+        <translation>Görsel Bilgileri</translation>
     </message>
     <message>
         <source>New album</source>
-        <translation>Yeni albüm</translation>
+        <translation>Yeni Albüm</translation>
     </message>
     <message>
         <source>Rename</source>
-        <translation>Yeniden adlandır</translation>
+        <translation>Yeniden Adlandır</translation>
     </message>
     <message>
         <source>Delete</source>
@@ -725,7 +720,7 @@
     <name>SlideShowPanel</name>
     <message>
         <source>End show</source>
-        <translation>Sunumu bitir</translation>
+        <translation>Sunumu Bitir</translation>
     </message>
     <message>
         <source>Pause/Play</source>
@@ -740,7 +735,7 @@
     </message>
     <message>
         <source>Switch effect</source>
-        <translation>Geçiş etkisi</translation>
+        <translation>Geçiş Etkisi</translation>
     </message>
     <message>
         <source>Duration</source>
@@ -748,7 +743,7 @@
     </message>
     <message>
         <source>Switch duration</source>
-        <translation>Geçiş süresi</translation>
+        <translation>Geçiş Süresi</translation>
     </message>
     <message>
         <source>second</source>
@@ -763,11 +758,11 @@
     </message>
     <message>
         <source>Image management</source>
-        <translation>Görsel yönetimi</translation>
+        <translation>Görsel Yönetimi</translation>
     </message>
     <message>
         <source>My favorite</source>
-        <translation>Sık kullandıklarım</translation>
+        <translation>Sık Kullandıklarım</translation>
     </message>
     <message>
         <source>1:1 Size</source>
@@ -775,27 +770,27 @@
     </message>
     <message>
         <source>Fit to window</source>
-        <translation>Pencereye sığdır</translation>
+        <translation>Pencereye Sığdır</translation>
     </message>
     <message>
         <source>Rotate counterclockwise</source>
-        <translation>Saat yönünün tersine döndür</translation>
+        <translation>Saat Yönünün Tersine Döndür</translation>
     </message>
     <message>
         <source>Rotate clockwise</source>
-        <translation>Saat yönünde döndür</translation>
-    </message>
-    <message>
-        <source>Throw to Trash</source>
-        <translation>Çöpe at</translation>
+        <translation>Saat Yönünde Döndür</translation>
     </message>
     <message>
         <source>Unfavorite</source>
-        <translation>Sık kullanılandan çıkar</translation>
+        <translation>Sık Kullanılandan Çıkar</translation>
     </message>
     <message>
         <source>Favorite</source>
-        <translation>Sık kullanılanlara ekle</translation>
+        <translation>Sık Kullanılanlara Ekle</translation>
+    </message>
+    <message>
+        <source>Delete</source>
+        <translation>Sil</translation>
     </message>
 </context>
 <context>
@@ -804,6 +799,10 @@
         <source>No image files found</source>
         <translation>Herhangi bir görsel dosyası bulunamadı</translation>
     </message>
+    <message>
+        <source>Open Image</source>
+        <translation>Görsel Aç</translation>
+    </message>
 </context>
 <context>
     <name>TimelineBTContent</name>
@@ -817,7 +816,7 @@
     </message>
     <message>
         <source>Manage sync</source>
-        <translation>Eşitleme yönetimi</translation>
+        <translation>Eşitleme Yönetimi</translation>
     </message>
     <message>
         <source>Syncing: </source>
@@ -840,11 +839,11 @@
     </message>
     <message>
         <source>Add to album</source>
-        <translation>Albüme ekle</translation>
+        <translation>Albüme Ekle</translation>
     </message>
     <message>
         <source>Add to new album</source>
-        <translation>Yeni albüme ekle</translation>
+        <translation>Yeni Albüme Ekle</translation>
     </message>
     <message>
         <source>View</source>
@@ -856,7 +855,7 @@
     </message>
     <message>
         <source>Slide show</source>
-        <translation>Saydam sunumu</translation>
+        <translation>Saydam Sunumu</translation>
     </message>
     <message>
         <source>Print</source>
@@ -868,39 +867,39 @@
     </message>
     <message>
         <source>Copy to clipboard</source>
-        <translation>Panoya kopyala</translation>
-    </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Çöpe at</translation>
+        <translation>Panoya Kopyala</translation>
     </message>
     <message>
         <source>Favorite</source>
-        <translation>Sık kullanılanlara ekle</translation>
+        <translation>Sık Kullanılanlara Ekle</translation>
     </message>
     <message>
         <source>Unfavorite</source>
-        <translation>Sık kullanılanlardan çıkar</translation>
+        <translation>Sık Kullanılanlardan Çıkar</translation>
     </message>
     <message>
         <source>Rotate clockwise</source>
-        <translation>Saat yönünde döndür</translation>
+        <translation>Saat Yönünde Döndür</translation>
     </message>
     <message>
         <source>Rotate counterclockwise</source>
-        <translation>Saat yönünün tersine döndür</translation>
+        <translation>Saat Yönünün Tersine Döndür</translation>
     </message>
     <message>
         <source>Set as wallpaper</source>
-        <translation>Duvar kağıdı olarak ayarla</translation>
+        <translation>Duvar Kağıdı Olarak Ayarla</translation>
     </message>
     <message>
         <source>Display in file manager</source>
-        <translation>Dosya yöneticisinde görüntüle</translation>
+        <translation>Dosya Yöneticisinde Görüntüle</translation>
     </message>
     <message>
         <source>Image info</source>
-        <translation>Görsel bilgileri</translation>
+        <translation>Görsel Bilgileri</translation>
+    </message>
+    <message>
+        <source>Delete</source>
+        <translation>Sil</translation>
     </message>
 </context>
 <context>
@@ -938,18 +937,18 @@
     </message>
     <message>
         <source>My favorite</source>
-        <translation>Sık kullandıklarım</translation>
+        <translation>Sık Kullandıklarım</translation>
     </message>
     <message>
         <source>Recent imported</source>
-        <translation>Son içe aktarılan</translation>
+        <translation>Son İçe Aktarılan</translation>
     </message>
 </context>
 <context>
     <name>TopToolbar</name>
     <message>
         <source>New album</source>
-        <translation>Yeni albüm</translation>
+        <translation>Yeni Albüm</translation>
     </message>
     <message>
         <source>Settings</source>
@@ -965,26 +964,30 @@
     </message>
     <message>
         <source>Dark theme</source>
-        <translation>Koyu tema</translation>
+        <translation>Koyu Tema</translation>
+    </message>
+    <message>
+        <source>Deepin Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
+        <translation>Deepin Görsel Görüntüleyici, modern bir arayüz ve akıcı bir başarım sunan bir görüntü izleme aracıdır.</translation>
     </message>
 </context>
 <context>
     <name>ViewPanel</name>
     <message>
         <source>Timeline</source>
-        <translation>Zaman tüneli</translation>
+        <translation>Zaman Tüneli</translation>
     </message>
     <message>
         <source>Add to album</source>
-        <translation>Albüme ekle</translation>
+        <translation>Albüme Ekle</translation>
     </message>
     <message>
         <source>Add to new album</source>
-        <translation>Yeni albüme ekle</translation>
+        <translation>Yeni Albüme Ekle</translation>
     </message>
     <message>
         <source>Exit fullscreen</source>
-        <translation>Tam ekrandan çık</translation>
+        <translation>Tam Ekrandan Çık</translation>
     </message>
     <message>
         <source>Fullscreen</source>
@@ -992,7 +995,7 @@
     </message>
     <message>
         <source>Slide show</source>
-        <translation>Saydam sunumu</translation>
+        <translation>Saydam Sunumu</translation>
     </message>
     <message>
         <source>Print</source>
@@ -1004,51 +1007,59 @@
     </message>
     <message>
         <source>Copy to clipboard</source>
-        <translation>Panoya kopyala</translation>
-    </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Çöpe at</translation>
+        <translation>Panoya Kopyala</translation>
     </message>
     <message>
         <source>Remove from album</source>
-        <translation>Albümden kaldır</translation>
+        <translation>Albümden Kaldır</translation>
     </message>
     <message>
         <source>Favorite</source>
-        <translation>Sık kullanılanlara ekle</translation>
+        <translation>Sık Kullanılanlara Ekle</translation>
     </message>
     <message>
         <source>Unfavorite</source>
-        <translation>Sık kullanılanlardan çıkar</translation>
+        <translation>Sık Kullanılanlardan Çıkar</translation>
     </message>
     <message>
         <source>Show navigation window</source>
-        <translation>Gezinme penceresini görüntüle</translation>
+        <translation>Gezinme Penceresini Görüntüle</translation>
     </message>
     <message>
         <source>Hide navigation window</source>
-        <translation>Gezinme penceresini gizle</translation>
+        <translation>Gezinme Penceresini Gizle</translation>
     </message>
     <message>
         <source>Rotate clockwise</source>
-        <translation>Saat yönünde döndür</translation>
+        <translation>Saat Yönünde Döndür</translation>
     </message>
     <message>
         <source>Rotate counterclockwise</source>
-        <translation>Saat yönünün tersine döndür</translation>
+        <translation>Saat Yönünün Tersine Döndür</translation>
     </message>
     <message>
         <source>Set as wallpaper</source>
-        <translation>Duvar kağıdı olarak ayarla</translation>
+        <translation>Duvar Kağıdı Olarak Ayarla</translation>
     </message>
     <message>
         <source>Display in file manager</source>
-        <translation>Dosya yöneticisinde görüntüle</translation>
+        <translation>Dosya Yöneticisinde Görüntüle</translation>
     </message>
     <message>
         <source>Image info</source>
-        <translation>Görsel bilgileri</translation>
+        <translation>Görsel Bilgileri</translation>
+    </message>
+    <message>
+        <source>Delete</source>
+        <translation>Sil</translation>
+    </message>
+    <message>
+        <source>Open Image</source>
+        <translation>Görsel Aç</translation>
+    </message>
+    <message>
+        <source>All images</source>
+        <translation>Tüm Görseller</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
