@@ -3,20 +3,12 @@
     <name>AboutDialog</name>
     <message>
         <source>Deepin Image Viewer</source>
-        <translation>Deepin Image Viewer</translation>
+        <translation>Переглядач зображень Deepin</translation>
     </message>
     <message>
         <source>Version:</source>
         <translation>Версія:</translation>
     </message>
-    <message>
-        <source>Deepin Image Viewer is a fashion &amp; smooth image manager.</source>
-        <translation>Deepin Image Viewer - це модний та плавний менеджер зображень.</translation>
-    </message>
-    <message>
-        <source>It is featured with image management, image viewing and basic image editing.</source>
-        <translation>Він призначений для керування зображеннями, перегляду зображень і основного редагування зображень.</translation>
-    </message>
 </context>
 <context>
     <name>AlbumBTContent</name>
@@ -53,7 +45,7 @@
     </message>
     <message>
         <source>OK</source>
-        <translation>OK</translation>
+        <translation>Гаразд</translation>
     </message>
     <message>
         <source>New album</source>
@@ -87,7 +79,7 @@
     </message>
     <message>
         <source>Delete</source>
-        <translation>Видалити</translation>
+        <translation>Вилучити</translation>
     </message>
 </context>
 <context>
@@ -125,7 +117,7 @@
     </message>
     <message>
         <source>Slide show</source>
-        <translation>Слайд шоу</translation>
+        <translation>Показ слайдів</translation>
     </message>
     <message>
         <source>Rename</source>
@@ -137,14 +129,14 @@
     </message>
     <message>
         <source>Delete</source>
-        <translation>Видалити</translation>
+        <translation>Вилучити</translation>
     </message>
 </context>
 <context>
     <name>Application</name>
     <message>
         <source>Deepin Image Viewer</source>
-        <translation>Deepin Image Viewer</translation>
+        <translation>Переглядач зображень Deepin</translation>
     </message>
 </context>
 <context>
@@ -162,7 +154,7 @@
     </message>
     <message>
         <source>OK</source>
-        <translation>OK</translation>
+        <translation>Гаразд</translation>
     </message>
     <message>
         <source>Are you sure to add the pictures to the album?</source>
@@ -212,7 +204,7 @@
     </message>
     <message>
         <source>Delete</source>
-        <translation>Видалити</translation>
+        <translation>Вилучити</translation>
     </message>
 </context>
 <context>
@@ -226,7 +218,7 @@
     <name>ImageView</name>
     <message>
         <source>This file contains multiple pages, please use Evince to view all pages.</source>
-        <translation type="unfinished"/>
+        <translation>Цей файл містить декілька сторінок, будь ласка, запустіть Evince для перегляду усіх сторінок.</translation>
     </message>
 </context>
 <context>
@@ -255,10 +247,6 @@
         <source>Copy to clipboard</source>
         <translation>Копіювати в буфер обміну</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Перемістити до смітнику</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Видалити з альбому</translation>
@@ -307,6 +295,10 @@
         <source>Add to new album</source>
         <translation>Додати до нового альбому</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Вилучити</translation>
+    </message>
 </context>
 <context>
     <name>Importer</name>
@@ -341,8 +333,8 @@
         <translation>Дата зміни</translation>
     </message>
     <message>
-        <source>Resolution</source>
-        <translation>Роздільна здатність</translation>
+        <source>Dimension</source>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>File size</source>
@@ -409,40 +401,47 @@
     <name>PrintOptionsPage</name>
     <message>
         <source>No scaling</source>
-        <translation type="unfinished"/>
+        <translation>Не масштабувати</translation>
     </message>
     <message>
         <source>Fit page to image</source>
-        <translation type="unfinished"/>
+        <translation>Вписати сторінку у зображення</translation>
     </message>
     <message>
         <source>Fit image to page</source>
-        <translation type="unfinished"/>
+        <translation>Вписати зображення у сторінку</translation>
     </message>
     <message>
         <source>Scale to:</source>
-        <translation type="unfinished"/>
+        <translation>Масштабувати:</translation>
     </message>
     <message>
         <source>Millimeters</source>
-        <translation type="unfinished"/>
+        <translation>Міліметри</translation>
     </message>
     <message>
         <source>Centimeters</source>
-        <translation type="unfinished"/>
+        <translation>Сантиметри</translation>
     </message>
     <message>
         <source>Inches</source>
-        <translation type="unfinished"/>
+        <translation>Дюйми</translation>
     </message>
     <message>
         <source>Image Position</source>
-        <translation type="unfinished"/>
+        <translation>Позиція зображення</translation>
     </message>
     <message>
         <source>Scaling</source>
-        <translation type="unfinished"/>
+        <translation>Масштаб</translation>
     </message>
+    <message>
+        <source>Image Settings</source>
+        <translation>Налаштування зображення</translation>
+    </message>
+</context>
+<context>
+    <name>PrintPreviewDialog</name>
     <message>
         <source>Image Settings</source>
         <translation type="unfinished"/>
@@ -547,10 +546,6 @@
         <source>Copy</source>
         <translation>Скопіювати</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Перемістити до смітнику</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Видалити з альбому</translation>
@@ -619,6 +614,10 @@
         <source>Display shortcuts</source>
         <translation>Показати ярлики</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Вилучити</translation>
+    </message>
 </context>
 <context>
     <name>ShortcutEditor</name>
@@ -672,10 +671,6 @@
         <source>Copy</source>
         <translation>Скопіювати</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Перемістити до смітнику</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Видалити з альбому</translation>
@@ -718,7 +713,7 @@
     </message>
     <message>
         <source>Delete</source>
-        <translation>Видалити</translation>
+        <translation>Вилучити</translation>
     </message>
 </context>
 <context>
@@ -771,31 +766,31 @@
     </message>
     <message>
         <source>1:1 Size</source>
-        <translation type="unfinished"/>
+        <translation>Розмір 1:1</translation>
     </message>
     <message>
         <source>Fit to window</source>
-        <translation type="unfinished"/>
+        <translation>Підібрати розмір за вікном</translation>
     </message>
     <message>
         <source>Rotate counterclockwise</source>
-        <translation type="unfinished"/>
+        <translation>Повернути проти годинникової стрілки</translation>
     </message>
     <message>
         <source>Rotate clockwise</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Throw to Trash</source>
-        <translation type="unfinished"/>
+        <translation>Повернути за годинниковою стрілкою</translation>
     </message>
     <message>
         <source>Unfavorite</source>
-        <translation type="unfinished"/>
+        <translation>Вилучити з улубленого</translation>
     </message>
     <message>
         <source>Favorite</source>
-        <translation type="unfinished"/>
+        <translation>Улюблене</translation>
+    </message>
+    <message>
+        <source>Delete</source>
+        <translation>Вилучити</translation>
     </message>
 </context>
 <context>
@@ -804,6 +799,10 @@
         <source>No image files found</source>
         <translation>Не знайдено файлів зображень</translation>
     </message>
+    <message>
+        <source>Open Image</source>
+        <translation>Відкрити зображення</translation>
+    </message>
 </context>
 <context>
     <name>TimelineBTContent</name>
@@ -870,10 +869,6 @@
         <source>Copy to clipboard</source>
         <translation>Копіювати в буфер обміну</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Перемістити до смітнику</translation>
-    </message>
     <message>
         <source>Favorite</source>
         <translation>Обране</translation>
@@ -902,6 +897,10 @@
         <source>Image info</source>
         <translation>Інформація про зображення</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Вилучити</translation>
+    </message>
 </context>
 <context>
     <name>TitleFrame</name>
@@ -967,6 +966,10 @@
         <source>Dark theme</source>
         <translation>Темна тема</translation>
     </message>
+    <message>
+        <source>Deepin Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
+        <translation>Переглядач зображень Deepin — програма для перегляду зображень із сучасним інтерфейсом та зручностями у користуванні.</translation>
+    </message>
 </context>
 <context>
     <name>ViewPanel</name>
@@ -1006,10 +1009,6 @@
         <source>Copy to clipboard</source>
         <translation>Копіювати в буфер обміну</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>Кинути в сміття</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>Видалити з альбому</translation>
@@ -1050,5 +1049,17 @@
         <source>Image info</source>
         <translation>Інформація про зображення</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>Вилучити</translation>
+    </message>
+    <message>
+        <source>Open Image</source>
+        <translation>Відкрити зображення</translation>
+    </message>
+    <message>
+        <source>All images</source>
+        <translation>усі зображення</translation>
+    </message>
 </context>
 </TS>
\ No newline at end of file
