@@ -9,14 +9,6 @@
         <source>Version:</source>
         <translation>版本：</translation>
     </message>
-    <message>
-        <source>Deepin Image Viewer is a fashion &amp; smooth image manager.</source>
-        <translation>深度看图是一款外观时尚，性能流畅的图片管理工具。</translation>
-    </message>
-    <message>
-        <source>It is featured with image management, image viewing and basic image editing.</source>
-        <translation>兼具了图片管理和图片查看功能，可以进行基本的图片编辑。</translation>
-    </message>
 </context>
 <context>
     <name>AlbumBTContent</name>
@@ -255,10 +247,6 @@
         <source>Copy to clipboard</source>
         <translation>复制到剪贴板</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>丢到回收站</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>从相册中移除</translation>
@@ -307,6 +295,10 @@
         <source>Add to new album</source>
         <translation>添加到新相册</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>删除</translation>
+    </message>
 </context>
 <context>
     <name>Importer</name>
@@ -341,8 +333,8 @@
         <translation>修改时间</translation>
     </message>
     <message>
-        <source>Resolution</source>
-        <translation>分辨率</translation>
+        <source>Dimension</source>
+        <translation>尺寸</translation>
     </message>
     <message>
         <source>File size</source>
@@ -378,7 +370,7 @@
     </message>
     <message>
         <source>ISO</source>
-        <translation>IOS感光度</translation>
+        <translation>ISO感光度</translation>
     </message>
     <message>
         <source>Max aperture</source>
@@ -448,6 +440,13 @@
         <translation>图像设置</translation>
     </message>
 </context>
+<context>
+    <name>PrintPreviewDialog</name>
+    <message>
+        <source>Image Settings</source>
+        <translation>图像设置</translation>
+    </message>
+</context>
 <context>
     <name>QObject</name>
     <message>
@@ -547,10 +546,6 @@
         <source>Copy</source>
         <translation>复制</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>丢到回收站</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>从相册中移除</translation>
@@ -619,6 +614,10 @@
         <source>Display shortcuts</source>
         <translation>显示快捷键</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>删除</translation>
+    </message>
 </context>
 <context>
     <name>ShortcutEditor</name>
@@ -672,10 +671,6 @@
         <source>Copy</source>
         <translation>复制</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>丢到回收站</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>从相册中移除</translation>
@@ -785,10 +780,6 @@
         <source>Rotate clockwise</source>
         <translation>顺时针旋转</translation>
     </message>
-    <message>
-        <source>Throw to Trash</source>
-        <translation>丢到回收站</translation>
-    </message>
     <message>
         <source>Unfavorite</source>
         <translation>取消收藏</translation>
@@ -797,6 +788,10 @@
         <source>Favorite</source>
         <translation>收藏</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>删除</translation>
+    </message>
 </context>
 <context>
     <name>ThumbnailWidget</name>
@@ -804,6 +799,10 @@
         <source>No image files found</source>
         <translation>没有发现图片文件</translation>
     </message>
+    <message>
+        <source>Open Image</source>
+        <translation>打开图片</translation>
+    </message>
 </context>
 <context>
     <name>TimelineBTContent</name>
@@ -870,10 +869,6 @@
         <source>Copy to clipboard</source>
         <translation>复制到剪贴板</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>丢到回收站</translation>
-    </message>
     <message>
         <source>Favorite</source>
         <translation>收藏</translation>
@@ -902,6 +897,10 @@
         <source>Image info</source>
         <translation>图片信息</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>删除</translation>
+    </message>
 </context>
 <context>
     <name>TitleFrame</name>
@@ -967,6 +966,10 @@
         <source>Dark theme</source>
         <translation>深色主题</translation>
     </message>
+    <message>
+        <source>Deepin Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
+        <translation>深度看图是一款外观时尚，性能流畅的图片查看工具。</translation>
+    </message>
 </context>
 <context>
     <name>ViewPanel</name>
@@ -1006,10 +1009,6 @@
         <source>Copy to clipboard</source>
         <translation>复制到剪贴板</translation>
     </message>
-    <message>
-        <source>Throw to trash</source>
-        <translation>丢到回收站</translation>
-    </message>
     <message>
         <source>Remove from album</source>
         <translation>从相册中移除</translation>
@@ -1050,5 +1049,17 @@
         <source>Image info</source>
         <translation>图片信息</translation>
     </message>
+    <message>
+        <source>Delete</source>
+        <translation>删除</translation>
+    </message>
+    <message>
+        <source>Open Image</source>
+        <translation>打开图片</translation>
+    </message>
+    <message>
+        <source>All images</source>
+        <translation>所有图片</translation>
+    </message>
 </context>
 </TS>
\ No newline at end of file
