@@ -34,9 +34,6 @@ AboutDialog::AboutDialog()
     setVersion(tr("Version:") + VERSION);
     //FIXME: acknowledgementLink is empty!
     setAcknowledgementLink("https://www.deepin.org/acknowledgments/deepin-image-viewer/");
-    setDescription(tr("Deepin Image Viewer is a fashion & smooth image manager.") +
-                   "\n" +
-                   tr("It is featured with image management, image viewing and basic image editing."));
 
     connect(this, SIGNAL(closed()), this, SLOT(deleteLater()));
 }
